**# Set up main data set


*Import data on regions 
import excel using "$root\raw-data\country_subregions_codes_.xlsx",clear firstrow
ren WIDcode country
keep country regionstandard
save "$work_data\temp_country_subregions_codes.dta",replace 

*Country name using Country Codes in https://wid.world/codes-dictionary/
 import excel using "$root\raw-data\country_subregions_codes_.xlsx",clear firstrow
 ren WIDcode country
save temp__.dta,replace


*Import PPP series for 2023
wid, ind(xlceup xlcusp) ag(999) pop(i) year(2023) clear
drop percentile age pop
reshape wide value, i(country) j(variable) string
rename valuexlceup999i ppp_2023_eur //PPP EUR
rename valuexlcusp999i ppp_2023_usd //PPP USD
drop year
save ppp_2023.dta,replace

gl variables "anninc mnninc mnnfin xlceux xlcusx mndpro mnwnxa mpinnx mcomnx  mtaxnx mscinx inyixx mnwnxa mpinnx mcomnx  mtaxnx mscinx mgdpro mnnfin mtbnnx   mtbxrx mtbmpx mrevgo mretgo mexpgo mntrgr mheage meduge msopge mpsugo minpgo xlceup xlcusp "/*mtgnnx   mtgxrx mtgmpx 		mtsnnx   mtsxrx mtsmpx*/

*Import data series from 1970 to 2023 (all but PPPs)
foreach var in npopul $variables{
	
	wid, ind(`var') ag(999) pop(i)  clear
	keep if year>=1970
	drop percentile  age pop 

	ren value `var' 

	save `var'.dta,replace
}


*Merge
use npopul.dta,clear
foreach var in  $variables{
	merge 1:1 year country using `var'.dta
	drop _merge
// 	cap erase `var'.dta
}
// cap erase npopul.dta
drop variable
merge m:1 country using ppp_2023.dta
	drop _merge
// cap erase ppp_2023.dta



*Rename relevant variables
rename xlcusx mer_usd 	//Market Exchange Rates (USD)
rename xlceux mer_eur 	//Market Exchange Rates (EUR)
rename mnnfin nfi 		//Net foreign income
rename mndpro ndp 		//Net domestic product
rename inyixx nipi 		//National income price index
rename npopul poptot 	//Total population
rename anninc nni_pc	//Net national income per capita
rename mnninc nni 		//Total net national income
// rename mnginc gni 		//Gross national income

rename mnwnxa nfw 		//Net foreign assets
rename mpinnx nfci 		//Net foreign capital income
rename mcomnx nfli 		//Net foreign labor income
rename mscinx nr 		//Net remittances
rename mtaxnx nfts 		//Net Foreign taxes 
rename mgdpro gdp 		//GDP
g gni=gdp+nfi			//Gross national income
// rename mtbnnx tb 		//Trade balance (exports-imports)
// rename mtbxrx exp 		//Exports of goods and services
// rename mtbmpx imp 		//Imports of goods and services

rename mtbxrx exp // exports (goods + services)
rename mtbmpx imp // imports (goods + services)
rename mtbnnx tb // trade balance
// rename mtgxrx exp_g // exports goods
// rename mtgmpx imp_g // imports goods
// rename mtgnnx tb_g // trade balance goods
// rename mtsxrx exp_s // exports services
// rename mtsmpx imp_g // imports services
// rename mtsnnx tb_g // trade balance services

rename mrevgo pr 		//Public revenue
rename mretgo tr 		//Tax revenue
rename mntrgr ntr 		//Non-tax revenue
rename mexpgo ps 		// Public spending
g ehs=mheage +meduge 	//Public spending in education and health
rename msopge sp 		//Public spending in social protection
g ops=ps-ehs-sp 		//Other public spending
rename mpsugo psur 		//Primary surplus
rename minpgo ip 		//Interest payment
g ssur=psur-ip 			//Secondary surplus
rename xlceup ppp_eur 	//PPP EUR
rename xlcusp ppp_usd 	//PPP USD

rename mheage psh		//Public spending in health
rename meduge pse 		//Public spending in education 

*Convert to current USD
g ndp_mer_usd=(nipi*ndp)/mer_usd //first multiply by inyixx then divide by xlcusx  
g nfi_mer_usd=(nipi*nfi)/mer_usd //first multiply by inyixx then divide by xlcusx 
g gdp_mer_usd=(nipi*gdp)/mer_usd //first multiply by inyixx then divide by xlcusx 
g nfw_mer_usd=(nipi*nfw)/mer_usd //first multiply by inyixx then divide by xlcusx
g nni_mer_usd=(nipi*nni)/mer_usd //first multiply by inyixx then divide by xlcusx

g ndp_ppp_2023_usd=(/*nipi**/ndp)/ppp_2023_usd 
g nfi_ppp_2023_usd=(/*nipi**/nfi)/ppp_2023_usd 
g gdp_ppp_2023_usd=(/*nipi**/gdp)/ppp_2023_usd 
g nfw_ppp_2023_usd=(/*nipi**/nfw)/ppp_2023_usd 
g nni_ppp_2023_usd=(/*nipi**/nni)/ppp_2023_usd 

*Generate Region variable
 gen region2=""
foreach c of global EURO {
	replace region2="EURO" if country=="`c'"
	}
foreach c of global NAOC {
	replace region2="NAOC" if country=="`c'"
	}
foreach c of global LATA {
	replace region2="LATA" if country=="`c'"
	}
foreach c of global MENA {
	replace region2="MENA" if country=="`c'"
	}
foreach c of global SSAF {
	replace region2="SSAF" if country=="`c'"
	}
foreach c of global RUCA {
	replace region2="RUCA" if country=="`c'"
	}
foreach c of global EASA {
	replace region2="EASA" if country=="`c'"
	}	
foreach c of global SSEA {
	replace region2="SSEA" if country=="`c'"
	}		
ren region2 region

replace region="World" if country=="WO"

*Classify according to total population
 g classif=""
 	 replace classif="0-100k" if  inrange(poptot,0,100000) 	
	 replace classif="100k-1m" if  inrange(poptot,100000,1000000) 	
	 replace classif="1m-10m" if  inrange(poptot,1000000,10000000) 	
	 replace classif="10m-50m" if  inrange(poptot,10000000,50000000) 	
	 replace classif="50m-100m" if  inrange(poptot,50000000,100000000) 	
	 replace classif="100m-500m" if  inrange(poptot,100000000,500000000) 	
	 replace classif="over 500m" if  poptot>=500000000 	
	 tab country if nni==.
	 
*Convert to PPP 2023
gen nni_ppp_2023_eur=nni/ppp_2023_eur
gen nni_mer_2023_eur=nni/mer_eur

*Format 	
g order=1 if region=="EASA"
	replace  order=2 if region=="EURO"
	replace  order=3 if region=="LATA"
	replace  order=4 if region=="MENA"
	replace  order=5 if region=="NAOC"
	replace  order=6 if region=="RUCA"
	replace  order=7 if region=="SSEA"
	replace  order=8 if region=="SSAF"
	replace  order=9 if region=="World"
	
g order_pop =1 if 		classif=="0-100k"  
	replace order_pop=2 if 	classif=="100k-1m" 
	replace order_pop=3 if 	classif=="1m-10m"  
	replace order_pop=4 if 	classif=="10m-50m"  
	replace order_pop=5 if 	classif=="50m-100m"  
	replace order_pop=6 if 	classif=="100m-500m" 
	replace order_pop=7 if 	classif=="over 500m" 	
	
*Merge to obtain the name of the region
merge m:1 country using "$work_data\temp_country_subregions_codes.dta"
br if _merge==1
tab regionstandard
replace regionstandard="Latin America" if country=="BL" //*BL;Saint Barthelemy;Saint Barthelemy;Americas;Caribbean
replace regionstandard="Europe" if country=="GG" //*GG;Guernsey;Guernsey;Europe;Western Europe
replace regionstandard="Europe" if country=="JE" //*JE;Jersey;Jersey;Europe;Western Europe
replace regionstandard="Europe" if country=="KS" //*KS;Kosovo;Kosovo;Europe;Eastern Europe
replace regionstandard="Latin America" if country=="MF" //*MF;Saint Martin (French part);Saint 	
replace regionstandard="Europe" if country=="GG" //*GG;Guernsey;Guernsey;Europe;Western Europe
// keep if _merge==3
drop _merge

*Merge to obtain the name of countries missing
 merge m:1 country using temp__.dta
 
 *Keep core countries
gen corecountry=.
foreach c of global corecountries {
	replace corecountry=1 if country=="`c'"
	}
keep if (corecountry==1 | country=="WO")

 replace countryname="Guernsey" if country=="GG" //*GG;Guernsey;Guernsey;Europe;Western Europe
replace regionstandard="Europe" if country=="JE" //*JE;Jersey;Jersey;Europe;Western Europe
replace countryname="Jersey" if country=="JE" //*JE;Jersey;Jersey;Europe;Western Europe
replace countryname="Kosovo" if country=="KS" //*KS;Kosovo;Kosovo;Europe;Eastern Europe	
drop _merge	
save main_dataset.dta,replace





**# Temporary raw file for PPP
*Temporary Obtainnew PPP
use "$root\raw-data\merge-historical-aggregates.dta",clear
keep if widcode=="xlceup999i" | widcode=="xlcusp999i"
keep if year==2023
// wid, ind(xlceup xlcusp) ag(999) pop(i) year(2023) clear
ren iso country
ren widcode variable
keep value country variable year
reshape wide value, i(country year) j(variable) string
rename valuexlceup999i ppp_2023_eur //PPP EUR
rename valuexlcusp999i ppp_2023_usd //PPP USD
drop year
save "$work_data\temp_new_ppp.dta", replace

use main_dataset.dta,clear
drop ppp_2023_eur ppp_2023_usd
merge m:1 country using "$work_data\temp_new_ppp.dta"
drop _merge
save main_dataset_temp.dta,replace
 