


**# Table 5
/*------------------------------------------------------------------------------
Table 5. Country Size by World Regions (2023)
------------------------------------------------------------------------------*/

use main_dataset.dta,clear
keep if year==2023

*Format
replace poptot=poptot/1000000 // in millions
drop if country=="WO"
 
*Generate relevant variables per region 
foreach region in EURO NAOC LATA MENA SSAF RUCA EASA  SSEA WO{
preserve	 
	 sum poptot if region=="`region'"
		 loc total_countries=r(N)
		 loc avg_pop=r(mean)
	 sum poptot if region=="`region'" & inrange(poptot,0,.1) 	
		 loc total_countries_100k=r(N)
	 sum poptot if region=="`region'" & inrange(poptot,.1,1) 	
		 loc total_countries_1m=r(N)	 
	 sum poptot if region=="`region'" & inrange(poptot,1,10) 	
		 loc total_countries_10m=r(N)	 	 
	 sum poptot if region=="`region'" & inrange(poptot,10,50) 	
		 loc total_countries_50m=r(N)	 	 	 
	 sum poptot if region=="`region'" & inrange(poptot,50,100) 	
		 loc total_countries_100m=r(N)	 	 	 	 
	 sum poptot if region=="`region'" & inrange(poptot,100,500) 	
		 loc total_countries_500m=r(N)	 	 	 	 	 
	 sum poptot if region=="`region'" & poptot>=500 	
		 loc total_countries_1b=r(N)	 	 	 	 	 	 

	 	g col0="`region'"
	g col1=`total_countries'
	g col2=`avg_pop'
	g col3=`total_countries_100k'
	g col4=`total_countries_1m'
	g col5=`total_countries_10m'
	g col6=`total_countries_50m'
	g col7=`total_countries_100m'
	g col8=`total_countries_500m'
	g col9=`total_countries_1b'
	
	keep col*
	duplicates drop
	
	save "$work_data\temp_`region'.dta", replace
	restore
}

*Generate relevant variables at the World level
	 sum poptot 
		 loc total_countries=r(N)
		 loc avg_pop=r(mean)
	 sum poptot if  inrange(poptot,0,.1) 	
		 loc total_countries_100k=r(N)
	 sum poptot if  inrange(poptot,.1,1) 	
		 loc total_countries_1m=r(N)	 
	 sum poptot if  inrange(poptot,1,10) 	
		 loc total_countries_10m=r(N)	 	 
	 sum poptot if  inrange(poptot,10,50) 	
		 loc total_countries_50m=r(N)	 	 	 
	 sum poptot if  inrange(poptot,50,100) 	
		 loc total_countries_100m=r(N)	 	 	 	 
	 sum poptot if  inrange(poptot,100,500) 	
		 loc total_countries_500m=r(N)	 	 	 	 	 
	 sum poptot if  poptot>=500 	
		 loc total_countries_1b=r(N)	 
		 
	 g col0="WO"
	g col1=`total_countries'
	g col2=`avg_pop'
	g col3=`total_countries_100k'
	g col4=`total_countries_1m'
	g col5=`total_countries_10m'
	g col6=`total_countries_50m'
	g col7=`total_countries_100m'
	g col8=`total_countries_500m'
	g col9=`total_countries_1b'		
	
	keep col*
	duplicates drop
	save "$work_data\temp_WO.dta", replace	

*Append in format for exporting	
use "$work_data\temp_EASA.dta", clear
append using "$work_data\temp_EURO.dta" 
append using "$work_data\temp_LATA.dta" 
append using "$work_data\temp_MENA.dta"
append using "$work_data\temp_NAOC.dta"
append using "$work_data\temp_RUCA.dta"
append using "$work_data\temp_SSEA.dta"
append using "$work_data\temp_SSAF.dta"
append using "$work_data\temp_WO.dta"
	
// *Export	
export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataT5", modify) cell(B5) keepcellfmt

*Erase temporary files
foreach region in EURO NAOC LATA MENA SSAF RUCA EASA  SSEA WO{
	cap erase "$work_data\temp_`region'.dta"
	}		
				
				
				
				

		
**# Table 6
/*------------------------------------------------------------------------------
Table 6. Per Capita National Income by Country Size (2023)
------------------------------------------------------------------------------*/
use main_dataset.dta,clear
keep if year==2023

*Format
drop if country=="WO"


  g countries=1

 *Compute for World 
preserve
collapse (sum) countries poptot nni_ppp_2023_eur 
sum countries
loc countries=r(mean)
sum poptot
loc poptot=r(mean)
sum nni_ppp_2023_eur
loc nni_ppp_2023_eur=r(mean)
g nni=nni_ppp_2023_eur/poptot
sum nni
loc nni=r(mean)
restore

 *Compute per category of country size
 collapse (sum) countries poptot nni_ppp_2023_eur  ,by(classif)
 
 *Include World 
set obs `=_N+1'
	replace classif="World" if classif==""
	replace countries=`countries' if classif=="World" & countries==.
	replace poptot=`poptot' if classif=="World" & poptot==.
	replace nni_ppp_2023_eur=`nni_ppp_2023_eur' if classif=="World" & nni_ppp_2023_eur==.

*Generate relevant variables	
g nni=nni_ppp_2023_eur/poptot
replace poptot=poptot/1000000
g sh_countries=100*countries/`countries'
g sh_poptot=100*poptot/(`poptot'/1000000)	
sum nni if classif=="World"
g sh_nni=100*nni/r(mean)

*Format for exporting		
drop nni_ppp_2023_eur
format nni %20.0f
order classif countries sh_countries poptot sh_poptot nni sh_nni
g order =1 if 		classif=="0-100k"  
	replace order=2 if 	classif=="100k-1m" 
	replace order=3 if 	classif=="1m-10m"  
	replace order=4 if 	classif=="10m-50m"  
	replace order=5 if 	classif=="50m-100m"  
	replace order=6 if 	classif=="100m-500m" 
	replace order=7 if 	classif=="over 500m" 
	replace order=8 if 	classif=="World"
sort order
drop order

*Export
export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataT6", modify) cell(B5) keepcellfmt			
		
		
		
		

**# Table 7
/*------------------------------------------------------------------------------
Table 7. Per Capita National Income and Country Size (2023)
------------------------------------------------------------------------------*/
use main_dataset.dta,clear
keep if year==2023

*Format
drop if country=="WO"


 *Sort from lowest to highest per capita net national income (PPP)
 g nni_ppp_2023_eur_pc=nni_ppp_2023_eur/poptot
 sort nni_ppp_2023_eur_pc
 
 *Classify according to per capita net national income
 egen seq=seq()
 g percentile=""
 replace percentile="0%-10%" if inrange(seq,1,22)
 replace percentile="10%-20%" if inrange(seq,23,44)
 replace percentile="20%-30%" if inrange(seq,45,66)
 replace percentile="30%-40%" if inrange(seq,67,87)
 replace percentile="40%-50%" if inrange(seq,88,108) 
 replace percentile="50%-60%" if inrange(seq,109,129)
 replace percentile="60%-70%" if inrange(seq,130,150)
 replace percentile="70%-80%" if inrange(seq,151,172)
 replace percentile="80%-90%" if inrange(seq,173,194)
 replace percentile="90%-100%" if inrange(seq,195,216) 
 
 *For Figure 2: top 10% countries
 preserve 
	 keep if percentile=="90%-100%"
	 keep country percentile
	 g top=1
	save "$work_data\temp_top10.dta",replace
 restore
 
 *Save temporary file with sample
 g countries=1
 save temp.dta,replace
 
 *Generate First 2 columns
 use temp.dta,clear
 g avg_pop=poptot
 g nni_ppp_2=nni_ppp_2023_eur

 *Compute for World 
preserve
	collapse (sum) countries poptot nni_ppp_2023_eur (mean) nni_ppp_2  avg_pop
	sum countries
	loc countries=r(mean)
	sum poptot
	loc poptot=r(mean)
	sum avg_pop
	loc avg_pop=r(mean)
	sum nni_ppp_2023_eur
	loc nni_ppp_2023_eur=r(mean)
	sum nni_ppp_2
	loc nni_ppp_2=r(mean)	

restore

 *Compute per percentile
format avg_pop %20.0f
 collapse (sum) countries poptot nni_ppp_2023_eur (mean) avg_pop ,by(percentile)
 
*Include World 
set obs `=_N+1'
	replace percentile="World" if percentile==""
	replace countries=`countries' if percentile=="World" & countries==.
	replace poptot=`poptot' if percentile=="World" & poptot==.
	replace avg_pop=`avg_pop' if percentile=="World" & avg_pop==.
	replace nni_ppp_2023_eur=`nni_ppp_2023_eur' if percentile=="World" & nni_ppp_2023_eur==.
	
*Format for exporting	
g nni_ppp=nni_ppp_2023_eur/poptot
	replace poptot=poptot/1000000
	replace avg_pop=avg_pop/1000000

drop countries poptot nni_ppp_2023_eur
order percentile nni avg_pop
save "$work_data\temp_percentiles.dta",replace
 
 *Generate columns for different sizes of countries
  use temp.dta,clear
  collapse (sum) countries ,by(classif percentile)
	g order =1 if 		classif=="0-100k"  
	replace order=2 if 	classif=="100k-1m" 
	replace order=3 if 	classif=="1m-10m"  
	replace order=4 if 	classif=="10m-50m"  
	replace order=5 if 	classif=="50m-100m"  
	replace order=6 if 	classif=="100m-500m" 
	replace order=7 if 	classif=="over 500m" 
	sort order
  drop classif
  reshape wide countries, i(percentile) j(order) 
save "$work_data\temp_countries_per_size.dta",replace	

*Merge
use "$work_data\temp_percentiles.dta",clear
merge 1:1 percentile using "$work_data\temp_countries_per_size.dta"
drop _merge
cap erase "$work_data\temp_percentiles.dta"
cap erase "$work_data\temp_countries_per_size.dta"
cap erase temp.dta

*Export
export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataT7", modify) cell(B5) keepcellfmt

		
		
**# Figure 2
/*------------------------------------------------------------------------------
Per Capita National Income and Country Size 1970-2023 
(2023 PPP €)
------------------------------------------------------------------------------*/

**Part 1: Select small countries
*Import data
use main_dataset.dta,clear
keep if year>=1970
drop if country=="WO"


*Select only small countries	
	keep if inlist(classif,"0-100k", "100k-1m", "1m-10m")
	
	

*Compute total
	g countries=1
	collapse (sum) countries ,by(order_pop year) 
	 
*Format for exporting	 
reshape wide countries , i(year) j(order_pop) 
ren countries1 c_0_100k
ren countries2 c_100k_1m
ren countries3 c_1m_10m

*Save Part 1
save "$work_data\total_small_countries.dta",replace


**Part 2: Compute total countries
*Import data
use main_dataset.dta,clear
keep if year>=1970
drop if country=="WO"
	
*Compute total	
g countries=1
collapse (sum) countries ,by(year) 

*Save Part 2
save "$work_data\total_countries.dta",replace


**Part 3: Compute shares
*Import data
use main_dataset.dta,clear
keep if year>=1970
drop if country=="WO"


*Select only small countries	
keep if inlist(classif,"0-100k", "100k-1m", "1m-10m")
	
*Merge with top 10 countries according to per national net national income
merge m:1 country using "$work_data\temp_top10.dta" //need to run Table 7 before

*Select only small countries and top 10 countries	
keep if inlist(classif,"0-100k", "100k-1m", "1m-10m") & top==1

*Compute total	
g countries=1
collapse (sum) countries ,by(order_pop year) 
	
*Format for exporting	
reshape wide countries , i(year) j(order_pop) 
ren countries1 c_0_100k_top10
ren countries2 c_100k_1m_top10
ren countries3 c_1m_10m_top10

*Merge with Parts 1 and 2
merge 1:1 year using "$work_data\total_small_countries.dta"
drop _merge
merge 1:1 year using "$work_data\total_countries.dta"
drop _merge
g top10_countries=22 //Based on instructions

*Compute relevant variables
g sh_c_0_100k=c_0_100k/countries
g sh_c_100k_1m=c_100k_1m/countries
g sh_c_1m_10m=c_1m_10m/countries
g sh_c_0_100k_top10=c_0_100k_top10/top10_countries
g sh_c_100k_1m_top10=c_100k_1m_top10/top10_countries
g sh_c_1m_10m_top10=c_1m_10m_top10/top10_countries
tsset year
tsline sh_c_0_100k sh_c_100k_1m sh_c_1m_10m

// *Export 
export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataF2", modify) cell(A4) keepcellfmt

*Erase temporal files
cap erase "$work_data\total_countries.dta"
cap erase "$work_data\total_small_countries.dta"
cap erase "$work_data\temp_top10.dta"
		
		
		
		


**# Figures 2b and 2c

/*------------------------------------------------------------------------------
Figure 2b Per Capita National Income by Country Size 1970-2023
(% of world average) -2023 PPP €-

Figure 2c Per Capita National Income by Country Size 1970-2023
(% of world average) -2023 PPP €- log scale
------------------------------------------------------------------------------*/


use main_dataset.dta,clear
keep if year==2023
keep country   classif
save classif_2023.dta,replace



forv year=1970/2023{
	

	use main_dataset.dta,clear
	keep if year==`year'
	drop classif

	merge 1:1 country using classif_2023.dta
	keep if _merge==3
	drop _merge


	*Format
	drop if country=="WO"

	merge 1:1 country using ppp_2023.dta
	keep if _merge==3
	drop _merge


	  g countries=1

	 *Compute for World 
	preserve
	collapse (sum) countries poptot nni_ppp_2023_eur
	sum countries
	loc countries=r(mean)
	sum poptot
	loc poptot=r(mean)
	sum nni_ppp_2023_eur
	loc nni_ppp_2023_eur=r(mean)
	g nni=nni_ppp_2023_eur/poptot
	sum nni
	loc nni=r(mean)
	restore

	 *Compute per category of country size
	 collapse (sum) countries poptot nni_ppp_2023_eur ,by(classif)
	 
	 *Include World 
	set obs `=_N+1'
		replace classif="World" if classif==""
		replace countries=`countries' if classif=="World" & countries==.
		replace poptot=`poptot' if classif=="World" & poptot==.
		replace nni_ppp_2023_eur=`nni_ppp_2023_eur' if classif=="World" & nni_ppp_2023_eur==.

	*Generate relevant variables	
	g nni=nni_ppp_2023_eur/poptot
	replace poptot=poptot/1000000
	g sh_countries=100*countries/`countries'
	g sh_poptot=100*poptot/(`poptot'/1000000)	
	sum nni if classif=="World"
	g sh_nni=100*nni/r(mean)

	*Format for exporting		
	drop nni_ppp_2023_eur
	format nni %20.0f
	order classif countries sh_countries poptot sh_poptot nni sh_nni
	g order =1 if 		classif=="0-100k"  
		replace order=2 if 	classif=="100k-1m" 
		replace order=3 if 	classif=="1m-10m"  
		replace order=4 if 	classif=="10m-50m"  
		replace order=5 if 	classif=="50m-100m"  
		replace order=6 if 	classif=="100m-500m" 
		replace order=7 if 	classif=="over 500m" 
		replace order=8 if 	classif=="World"
	sort order
	drop order

	keep classif sh_nni
	g year=`year'
	drop if classif=="World"
	loc s classif 
			replace `s' = subinstr(`s', "-", "_", .)
			replace `s' = subinstr(`s', " ", "_", .)
	reshape wide sh_nni, i(year) j(classif) string

	save data`year'.dta,replace
}

use data1970.dta,clear
forv year=1971/2023{
append using data`year'.dta	
cap erase data`year'.dta	
}
cap erase data1970.dta
sort year 

tsset year
tsline sh_nni0_100k sh_nni100k_1m sh_nni100m_500m sh_nni10m_50m sh_nni1m_10m sh_nni50m_100m sh_nniover_500m, xline(1979 2005 2014)
drop year
*Export
export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataF2_b", modify) cell(B4) keepcellfmt			
						
		
		
		
		
**# Figures 2d-2g 
/*------------------------------------------------------------------------------
Equivalent to Figure 2b Per Capita National Income by Country Size 1970-2023
(% of world average) -2023 PPP €-
for regions EURO, LATA, NAOC, and SSA
------------------------------------------------------------------------------*/
use main_dataset.dta,clear
drop classif
merge m:1 country using classif_2023.dta
keep if _merge==3
drop _merge


*Format
drop nni
g nni=nni_ppp_2023_eur/poptot

preserve
collapse (mean ) nni ,by(year)
ren nni nni_world
save nni_world.dta,replace
restore
merge m:1 year using nni_world.dta
keep if _merge==3
drop _merge
g sh_nni=100*nni/nni_world
keep if classif=="0-100k" 



keep country poptot nni_ppp_2023_eur year sh_nni
tab country


drop nni_ppp_2023_eur poptot nni
reshape wide sh_nni, i(year) j(country) string

tsset year
tsline sh_nniAD sh_nniAG sh_nniAI  sh_nniBM sh_nniBQ sh_nniDM  sh_nniGG sh_nniGI sh_nniGL sh_nniIM  sh_nniKN sh_nniKY sh_nniLI sh_nniMC sh_nniMH sh_nniMS sh_nniNR sh_nniPW sh_nniSM  sh_nniSX sh_nniTC  sh_nniTV  sh_nniVG 

*Europe
label var sh_nniAD Andorra
label var sh_nniGG Guernsey
label var sh_nniGI Gibraltar
label var sh_nniGL Greenland
label var sh_nniIM IsleOfMan
label var sh_nniLI Liechtenstein
label var sh_nniMC Monaco
label var sh_nniSM 	SanMarino


*LATAM
label var sh_nniAG AntiguaAndBarbuda 
label var sh_nniAI Anguilla
label var sh_nniBQ Bonaire
label var sh_nniDM Dominica
label var sh_nniKN 	SaintKittsAndNevis
label var sh_nniKY 	CaymanIslands
label var sh_nniSX SintMaarten
label var sh_nniTC TurksAndCaicosIslandsGrenadines
label var sh_nniVG BritishVirginIslands 

*NAOC
label var sh_nniBM Bermuda
label var sh_nniMH MarshallIslands
label var sh_nniNR Nauru
label var sh_nniPW Palau
label var sh_nniTV Tuvalu

*SSA
label var sh_nniMS Mauritania



tsline sh_nniAD sh_nniAG sh_nniAI  sh_nniBM sh_nniBQ sh_nniDM  sh_nniGG sh_nniGI sh_nniGL sh_nniIM sh_nniKN sh_nniKY sh_nniLI sh_nniMC sh_nniMH sh_nniMS sh_nniNR sh_nniPW  sh_nniSM  sh_nniSX sh_nniTC sh_nniTV  sh_nniVG 

tsline sh_nniMS , title("Per Capita National Income in Sub Saharan Africa 1970-2023" "(% of world average) -PPP- ") note("Note: Countries with populations between 0 and 100k in 2023.") legend(row(1)) 

tsline  sh_nniBM    sh_nniMH   sh_nniNR   sh_nniPW   sh_nniTV    , title("Per Capita National Income in" "North America and Oceania 1970-2023" "(% of world average) -PPP- ") note("Note: Countries with populations between 0 and 100k in 2023.") lpattern(dash) legend(row(2))


tsline  sh_nniAD   sh_nniGG sh_nniGI sh_nniGL sh_nniIM  sh_nniLI sh_nniMC sh_nniSM 	, title("Per Capita National Income in" "Europe 1970-2023" "(% of world average) -PPP- ") note("Note: Countries with populations between 0 and 100k in 2023.") lpattern(dash dash dash) legend(row(2))



tsline  sh_nniAG   sh_nniAI  sh_nniBQ   sh_nniDM   sh_nniKN   sh_nniKY   sh_nniSX   sh_nniTC    sh_nniVG , title("Per Capita National Income in" "Latin America and the Caribean 1970-2023" "(% of world average) -PPP- ") note("Note: Countries with populations between 0 and 100k in 2023.") lpattern(dash dash dash dash dash dash shortdash shortdash shortdash shortdash  ) legend(row(4))

tsline  sh_nniBM  sh_nniKY  , title("Per Capita National Income" "(% of world average) -PPP- ") note("Note: Countries with populations between 0 and 100k in 2023.")


*Europe
rename sh_nniAD Andorra
rename sh_nniGG Guernsey
rename sh_nniGI Gibraltar
rename sh_nniGL Greenland
rename sh_nniIM IsleOfMan
rename sh_nniLI Liechtenstein
rename sh_nniMC Monaco
rename sh_nniSM 	SanMarino


*LATAM
rename sh_nniAG AntiguaAndBarbuda 
rename sh_nniAI Anguilla
rename sh_nniBQ Bonaire
rename sh_nniDM Dominica
rename sh_nniKN 	SaintKittsAndNevis
rename sh_nniKY 	CaymanIslands
rename sh_nniSX SintMaarten
rename sh_nniTC TurksAndCaicosIslands
rename sh_nniVG BritishVirginIslands 

*NAOC
rename sh_nniBM Bermuda
rename sh_nniMH MarshallIslands
rename sh_nniNR Nauru
rename sh_nniPW Palau
rename sh_nniTV Tuvalu

*SSA
rename sh_nniMS Mauritania

drop year
*Export
export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataF2_b_region", modify) cell(B4) keepcellfmt	

		
		
		
		


**# Tables 8a and 8b
/*------------------------------------------------------------------------------
Table 8a. Top 10 Richest Countries (2023)

Table 8b. Top 10 Richest Countries (2023), excluding countries with population below 10
------------------------------------------------------------------------------*/
**Part 1: All Countries
*Import data
use main_dataset.dta,clear
keep if year==2023
drop if country=="WO"

g nfi_ppp_2023=nfi/ppp_2023_eur
g nfw_ppp_2023=nfw/ppp_2023_eur
g ndp_ppp_2023=ndp/ppp_2023_eur
g nni_mer=nni/mer_eur

*Gnerate ratio Ratio between MER and PPP Per Capita National Income
g nni_mer_ppp_ratio=ppp_eur/mer_eur
g nfi_ratio=nfi_ppp_2023/ndp_ppp_2023
g nfw_ratio=nfw_ppp_2023/ndp_ppp_2023

 *Select top 10 countries according to per capita net national income  (PPP)
 g nni_ppp_2023_eur_pc=nni_ppp_2023_eur/poptot
 sort nni_ppp_2023_eur_pc
 egen seq=seq()
 g percentile=""
	 replace percentile="0%-10%" if inrange(seq,1,22)
	 replace percentile="10%-20%" if inrange(seq,23,44)
	 replace percentile="20%-30%" if inrange(seq,45,66)
	 replace percentile="30%-40%" if inrange(seq,67,87)
	 replace percentile="40%-50%" if inrange(seq,88,108) 
	 replace percentile="50%-60%" if inrange(seq,109,129)
	 replace percentile="60%-70%" if inrange(seq,130,150)
	 replace percentile="70%-80%" if inrange(seq,151,172)
	 replace percentile="80%-90%" if inrange(seq,173,194)
	 replace percentile="90%-100%" if inrange(seq,195,216) 
 keep if percentile=="90%-100%" 
 gsort -seq
 egen top10=seq()
 keep if inrange(top10,1,10)
 

*Format for exporting
order countryname nni_ppp_2023_eur_pc poptot nfi_ratio nni_mer_ppp nfw_ratio
keep countryname nni_ppp_2023_eur_pc poptot nfi_ratio nni_mer_ppp top10 nfw_ratio
foreach var in countryname nni_ppp_2023_eur_pc poptot nfi_ratio nni_mer_ppp nfw_ratio{
	ren `var' `var'_all
}

*Save Part 1
save "$work_data\top10_richest_all.dta",replace



**Part 2 (Only Small Countries)
*Import data
use main_dataset.dta,clear
keep if year==2023
drop if country=="WO"

g nfi_ppp_2023=nfi/ppp_2023_eur
g nfw_ppp_2023=nfw/ppp_2023_eur
g ndp_ppp_2023=ndp/ppp_2023_eur
g nni_mer=nni/mer_eur

*Gnerate ratio Ratio between MER and PPP Per Capita National Income
g nni_mer_ppp_ratio=ppp_eur/mer_eur
g nfi_ratio=nfi_ppp_2023/ndp_ppp_2023
g nfw_ratio=nfw_ppp_2023/ndp_ppp_2023

 *Select top 10 countries according to per capita net national income  (PPP)
 g nni_ppp_2023_eur_pc=nni_ppp_2023_eur/poptot
 sort nni_ppp_2023_eur_pc
 g countries=1

 
 egen seq=seq()
 g percentile=""
	 replace percentile="0%-10%" if inrange(seq,1,22)
	 replace percentile="10%-20%" if inrange(seq,23,44)
	 replace percentile="20%-30%" if inrange(seq,45,66)
	 replace percentile="30%-40%" if inrange(seq,67,87)
	 replace percentile="40%-50%" if inrange(seq,88,108) 
	 replace percentile="50%-60%" if inrange(seq,109,129)
	 replace percentile="60%-70%" if inrange(seq,130,150)
	 replace percentile="70%-80%" if inrange(seq,151,172)
	 replace percentile="80%-90%" if inrange(seq,173,194)
	 replace percentile="90%-100%" if inrange(seq,195,216) 

 drop if inlist(classif,"0-100k", "100k-1m","1m-10m")
 gsort -seq
 egen top10=seq()
 keep if inrange(top10,1,10)
 
 sort top10

*Format for exporting
order countryname nni_ppp_2023_eur_pc poptot nfi_ratio nni_mer_ppp nfw_ratio
keep countryname nni_ppp_2023_eur_pc poptot nfi_ratio nni_mer_ppp top10 nfw_ratio
*Merge with Part 1
merge 1:1 top10 using "$work_data\top10_richest_all.dta"
drop _merge
order top10 countryname_all nni_ppp_2023_eur_pc_all poptot_all nfi_ratio_all nni_mer_ppp_all countryname nni_ppp_2023_eur_pc poptot nfi_ratio nni_mer_ppp_ratio nfw_ratio_all nfw_ratio
keep top10 countryname_all nni_ppp_2023_eur_pc_all poptot_all nfi_ratio_all nni_mer_ppp_all countryname nni_ppp_2023_eur_pc poptot nfi_ratio nni_mer_ppp_ratio nfw_ratio_all nfw_ratio
cap erase "$work_data\top10_richest_all.dta"

*Export to excel
export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataT8", modify) cell(A4) keepcellfmt		





