


**# Table 9
/*------------------------------------------------------------------------------
Table 9. Bottom 10 Poorest Countries (2023)
------------------------------------------------------------------------------*/
**Part 1 (all Countries)
*Import data
use main_dataset.dta,clear
keep if year==2023
drop if country=="WO"

g nfi_ppp_2023=nfi/ppp_2023_eur
g nfw_ppp_2023=nfw/ppp_2023_eur
g ndp_ppp_2023=ndp/ppp_2023_eur
g nni_mer=nni/mer_eur

*Gnerate ratio Ratio between MER and PPP Per Capita National Income
g nni_mer_ppp_ratio=ppp_eur/mer_eur
g nfi_ratio=nfi_ppp_2023/ndp_ppp_2023
g nfw_ratio=nfw_ppp_2023/ndp_ppp_2023

 *Select top 10 countries according to per capita net national income  (PPP)
 g nni_ppp_2023_eur_pc=nni_ppp_2023_eur/poptot
 sort nni_ppp_2023_eur_pc
 egen seq=seq()
 g percentile=""
	 replace percentile="0%-10%" if inrange(seq,1,22)
	 replace percentile="10%-20%" if inrange(seq,23,44)
	 replace percentile="20%-30%" if inrange(seq,45,66)
	 replace percentile="30%-40%" if inrange(seq,67,87)
	 replace percentile="40%-50%" if inrange(seq,88,108) 
	 replace percentile="50%-60%" if inrange(seq,109,129)
	 replace percentile="60%-70%" if inrange(seq,130,150)
	 replace percentile="70%-80%" if inrange(seq,151,172)
	 replace percentile="80%-90%" if inrange(seq,173,194)
	 replace percentile="90%-100%" if inrange(seq,195,216) 
 keep if percentile=="0%-10%" 
 sort seq
 egen top10=seq()
 keep if inrange(top10,1,10)
 

sort top10

*Format for exporting
order countryname nni_ppp_2023_eur_pc poptot nfi_ratio nni_mer_ppp nfw_ratio
keep countryname nni_ppp_2023_eur_pc poptot nfi_ratio nni_mer_ppp top10 nfw_ratio
foreach var in countryname nni_ppp_2023_eur_pc poptot nfi_ratio nni_mer_ppp nfw_ratio{
	ren `var' `var'_all
}

*Save Part 1
save "$work_data\top10_poorest_all.dta",replace



**Part 2 (Only Small Countries)
*Import data
use main_dataset.dta,clear
keep if year==2023
drop if country=="WO"

g nfi_ppp_2023=nfi/ppp_2023_eur
g nfw_ppp_2023=nfw/ppp_2023_eur
g ndp_ppp_2023=ndp/ppp_2023_eur
g nni_mer=nni/mer_eur

*Gnerate ratio Ratio between MER and PPP Per Capita National Income
g nni_mer_ppp_ratio=ppp_eur/mer_eur
g nfi_ratio=nfi_ppp_2023/ndp_ppp_2023
g nfw_ratio=nfw_ppp_2023/ndp_ppp_2023

 *Select top 10 countries according to per capita net national income  (PPP)
 g nni_ppp_2023_eur_pc=nni_ppp_2023_eur/poptot
 sort nni_ppp_2023_eur_pc

 
 egen seq=seq()
 g percentile=""
 replace percentile="0%-10%" if inrange(seq,1,22)
 replace percentile="10%-20%" if inrange(seq,23,44)
 replace percentile="20%-30%" if inrange(seq,45,66)
 replace percentile="30%-40%" if inrange(seq,67,87)
 replace percentile="40%-50%" if inrange(seq,88,108) 
 replace percentile="50%-60%" if inrange(seq,109,129)
 replace percentile="60%-70%" if inrange(seq,130,150)
 replace percentile="70%-80%" if inrange(seq,151,172)
 replace percentile="80%-90%" if inrange(seq,173,194)
 replace percentile="90%-100%" if inrange(seq,195,216) 
 
 drop if inlist(classif,"0-100k", "100k-1m","1m-10m")
 sort seq
 egen top10=seq()
 keep if inrange(top10,1,10)
 

 
*Format for exporting
order countryname nni_ppp_2023_eur_pc poptot nfi_ratio nni_mer_ppp nfw_ratio
keep countryname nni_ppp_2023_eur_pc poptot nfi_ratio nni_mer_ppp top10 nfw_ratio
*Merge with Part 1
merge 1:1 top10 using "$work_data\top10_poorest_all.dta"
drop _merge
order top10 countryname_all nni_ppp_2023_eur_pc_all poptot_all nfi_ratio_all nni_mer_ppp_all countryname nni_ppp_2023_eur_pc poptot nfi_ratio nni_mer_ppp_ratio nfw_ratio_all nfw_ratio
keep top10 countryname_all nni_ppp_2023_eur_pc_all poptot_all nfi_ratio_all nni_mer_ppp_all countryname nni_ppp_2023_eur_pc poptot nfi_ratio nni_mer_ppp_ratio nfw_ratio_all nfw_ratio
cap erase "$work_data\top10_poorest_all.dta"

*Export to excel
export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataT9", modify) cell(A4) keepcellfmt






**# Table 10 
/*------------------------------------------------------------------------------
Table 10. Top 10 Largest Economies (2023)
------------------------------------------------------------------------------*/
*Import data
use main_dataset.dta,clear
keep if year==2023
drop if country=="WO"

g nfi_ppp_2023=nfi/ppp_2023_eur
g ndp_ppp_2023=ndp/ppp_2023_eur
g nni_mer=nni/mer_eur

*Gnerate ratio Ratio between MER and PPP Per Capita National Income
g nni_mer_ppp_ratio=ppp_eur/mer_eur
g nfi_ratio=nfi_ppp_2023/ndp_ppp_2023

 *Select top 10 countries according to per capita net national income  (PPP)
 g nni_ppp_2023_eur_pc=nni_ppp_2023_eur/poptot
 
gsort -nni_mer
egen rank_mer=seq()
 
*Select top 10 countries according to total net national income (ppp)
 gsort -nni_ppp_2023_eur
 egen seq=seq()
 sort seq
 egen top10=seq()
 keep if inrange(top10,1,10)
 
 preserve
 keep country countryname
 save largest.dta,replace
 restore
 
sort top10

*Format for exporting
order countryname nni_ppp_2023_eur poptot nni_ppp_2023_eur_pc nni_mer nni_mer_ppp_ratio
replace nni_ppp_2023_eur=nni_ppp_2023_eur/1000000000
replace nni_mer=nni_mer/1000000000
replace poptot=poptot/1000000

g nfi_mer_ratio=nfi_mer_usd/ndp_mer_usd
g nfw_mer_ratio=nfw_mer_usd/nni_mer_usd

*Export to excel
keep countryname nni_ppp_2023_eur poptot nni_ppp_2023_eur_pc nni_mer rank_mer nni_mer_ppp_ratio nfi_mer_ratio nfw_mer_ratio
order countryname nni_ppp_2023_eur poptot nni_ppp_2023_eur_pc nni_mer rank_mer nni_mer_ppp_ratio nfi_mer_ratio nfw_mer_ratio
export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataT10", modify) cell(A4) keepcellfmt




**# Table 11 
/*------------------------------------------------------------------------------
Table 11. Bottom 10 smallest economies, excluding countries with population <10m (2023)
------------------------------------------------------------------------------*/
*Import data
use main_dataset.dta,clear
keep if year==2023
drop if country=="WO"

g nfi_ppp_2023=nfi/ppp_2023_eur
g ndp_ppp_2023=ndp/ppp_2023_eur
g nni_mer=nni/mer_eur

*Gnerate ratio Ratio between MER and PPP Per Capita National Income
g nni_mer_ppp_ratio=ppp_eur/mer_eur
g nfi_ratio=nfi_ppp_2023/ndp_ppp_2023

 *Select top 10 countries according to per capita net national income  (PPP)
 g nni_ppp_2023_eur_pc=nni_ppp_2023_eur/poptot
 


 
*Select top 10 countries according to total net national income (ppp)
drop if poptot<10000000
 sort nni_ppp_2023_eur
 egen seq=seq()
 sort seq
 egen top10=seq()
 keep if inrange(top10,1,10)
 
  sort nni_mer
egen rank_mer=seq()
sort top10

*Format for exporting
order countryname nni_ppp_2023_eur poptot nni_ppp_2023_eur_pc nni_mer nni_mer_ppp_ratio
replace nni_ppp_2023_eur=nni_ppp_2023_eur/1000000000
replace nni_mer=nni_mer/1000000000
replace poptot=poptot/1000000

g nfi_mer_ratio=nfi_mer_usd/ndp_mer_usd
g nfw_mer_ratio=nfw_mer_usd/nni_mer_usd

*Export to excel
keep countryname nni_ppp_2023_eur poptot nni_ppp_2023_eur_pc nni_mer rank_mer nni_mer_ppp_ratio nfi_mer_ratio nfw_mer_ratio
order countryname nni_ppp_2023_eur poptot nni_ppp_2023_eur_pc nni_mer rank_mer nni_mer_ppp_ratio nfi_mer_ratio nfw_mer_ratio
export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataT11", modify) cell(A4) keepcellfmt




**# Tables 12a and 12b
/*------------------------------------------------------------------------------
Table 12a. Per Capita Net Domestic Product and Foreign Income (PPP 2023 €)

Table 12b. Per Capita Net Domestic Product and Foreign Income (2023, MER €)
------------------------------------------------------------------------------*/
*Import data
use main_dataset.dta,clear
keep if year==2023
drop if country=="WO"

g ndp_ppp_pc=(ndp/ppp_2023_eur)/poptot
foreach var in ndp nfi nfw nfci nfli nr nfts{
g `var'_ppp=(`var'/ppp_2023_eur)
g `var'_mer=(`var'/mer_eur)	
}




 *Sort from lowest to highest per capita net domestic product PPP
 sort ndp_ppp_pc
 
 *Classify according to per capita net national income
 egen seq=seq()
 g percentile=""
 replace percentile="0%-10%" if inrange(seq,1,22)
 replace percentile="10%-20%" if inrange(seq,23,44)
 replace percentile="20%-30%" if inrange(seq,45,66)
 replace percentile="30%-40%" if inrange(seq,67,87)
 replace percentile="40%-50%" if inrange(seq,88,108) 
 replace percentile="50%-60%" if inrange(seq,109,129)
 replace percentile="60%-70%" if inrange(seq,130,150)
 replace percentile="70%-80%" if inrange(seq,151,172)
 replace percentile="80%-90%" if inrange(seq,173,194)
 replace percentile="90%-100%" if inrange(seq,195,216) 


*Save temporary file with sample
 save temp.dta,replace
 
 *Generate First 2 columns
 use temp.dta,clear
 
 *Compute for World 
preserve
	collapse (sum) poptot  ndp_ppp nfi_ppp nfw_ppp 		nfci_ppp nfli_ppp nfts_ppp nr_ppp		ndp_mer nfi_mer nfw_mer nfci_mer nfli_mer nfts_mer nr_mer  	/*ndp_ppp_usd ndp_mer_usd */
	sum poptot
	loc poptot=r(mean)
	sum ndp_ppp
	loc ndp_ppp=r(mean)
	loc ndp_ppp_pc=`ndp_ppp'/`poptot'
	loc nfi_ppp_ratio=nfi_ppp/ndp_ppp
	loc nfw_ppp_ratio=nfw_ppp/ndp_ppp	
	loc nfci_ppp_ratio=nfci_ppp/ndp_ppp
	loc nfli_ppp_ratio=nfli_ppp/ndp_ppp	
	loc nr_ppp_ratio=nr_ppp/ndp_ppp
	loc nfts_ppp_ratio=nfts_ppp/ndp_ppp
	
	sum ndp_mer
	loc ndp_mer=r(mean)
	loc ndp_mer_pc=`ndp_mer'/`poptot'	

	loc nfi_mer_ratio=nfi_mer/ndp_mer
	loc nfw_mer_ratio=nfw_mer/ndp_mer
	loc nfci_mer_ratio=nfci_mer/ndp_mer
	loc nfli_mer_ratio=nfli_mer/ndp_mer	
	loc nr_mer_ratio=nr_mer/ndp_mer
	loc nfts_mer_ratio=nfts_mer/ndp_mer
	
	loc ndp_mer_ppp_pc_ratio=`ndp_mer_pc'/`ndp_ppp_pc'	
	


restore

 *Compute per percentile
 collapse (sum) poptot  ndp_ppp nfi_ppp nfw_ppp 		nfci_ppp nfli_ppp nfts_ppp nr_ppp		ndp_mer nfi_mer nfw_mer nfci_mer nfli_mer nfts_mer nr_mer 		/*ndp_ppp_usd ndp_mer_usd */,by(percentile)
 
g ndp_ppp_pc=ndp_ppp/poptot
g nfi_ppp_ratio=nfi_ppp/ndp_ppp
g nfw_ppp_ratio=nfw_ppp/ndp_ppp
g nfci_ppp_ratio=nfci_ppp/ndp_ppp
g nfli_ppp_ratio=nfli_ppp/ndp_ppp
g nr_ppp_ratio=nr_ppp/ndp_ppp
g nfts_ppp_ratio=nfts_ppp/ndp_ppp

g ndp_mer_pc=ndp_mer/poptot

g nfi_mer_ratio=nfi_mer/ndp_mer
g nfw_mer_ratio=nfw_mer/ndp_mer
g nfci_mer_ratio=nfci_mer/ndp_mer
g nfli_mer_ratio=nfli_mer/ndp_mer
g nr_mer_ratio=nr_mer/ndp_mer
g nfts_mer_ratio=nfts_mer/ndp_mer

g ndp_mer_ppp_pc_ratio=ndp_mer_pc/ndp_ppp_pc 

// g ndp_mer_ppp_ratio_usd=ndp_mer_usd/ndp_ppp_usd
 
*Include World 
set obs `=_N+1'
	replace percentile="World" if percentile==""
	replace ndp_ppp_pc=`ndp_ppp_pc' if percentile=="World" & ndp_ppp_pc==.
	replace nfi_ppp_ratio=`nfi_ppp_ratio' if percentile=="World" & nfi_ppp_ratio==.
	replace nfw_ppp_ratio=`nfw_ppp_ratio' if percentile=="World" & nfw_ppp_ratio==.	
	replace nfci_ppp_ratio=`nfci_ppp_ratio' if percentile=="World" & nfci_ppp_ratio==.	
	replace nfli_ppp_ratio=`nfli_ppp_ratio' if percentile=="World" & nfli_ppp_ratio==.	
	replace nfts_ppp_ratio=`nfts_ppp_ratio' if percentile=="World" & nfts_ppp_ratio==.
	replace nr_ppp_ratio=`nr_ppp_ratio' if percentile=="World" & nr_ppp_ratio==.	
	
	replace ndp_mer_pc=`ndp_mer_pc' if percentile=="World" & ndp_mer_pc==.
	replace ndp_mer_ppp_pc_ratio=`ndp_mer_ppp_pc_ratio' if percentile=="World" & ndp_mer_ppp_pc_ratio==.
	replace nfi_mer_ratio=`nfi_mer_ratio' if percentile=="World" & nfi_mer_ratio==.
	replace nfw_mer_ratio=`nfw_mer_ratio' if percentile=="World" & nfw_mer_ratio==.	
	replace nfci_mer_ratio=`nfci_mer_ratio' if percentile=="World" & nfci_mer_ratio==.	
	replace nfli_mer_ratio=`nfli_mer_ratio' if percentile=="World" & nfli_mer_ratio==.	
	replace nfts_mer_ratio=`nfts_mer_ratio' if percentile=="World" & nfts_mer_ratio==.
	replace nr_mer_ratio=`nr_mer_ratio' if percentile=="World" & nr_mer_ratio==.
	
	replace ndp_mer_ppp_pc_ratio=`ndp_mer_ppp_pc_ratio' if percentile=="World" & ndp_mer_ppp_pc_ratio==.

	
*Format for exporting	
order percentile ndp_ppp_pc nfi_ppp_ratio nfw_ppp_ratio nfci_ppp_ratio nfli_ppp_ratio nfts_ppp_ratio nr_ppp_ratio ndp_mer_pc ndp_mer_ppp_pc_ratio /*ndp_mer_ppp_ratio_usd*/ nfi_mer_ratio nfw_mer_ratio nfci_mer_ratio nfli_mer_ratio nfts_mer_ratio nr_mer_ratio
drop poptot ndp_ppp nfi_ppp nfw_ppp ndp_mer nfi_mer nfw_mer nfci_mer nfli_mer nfts_mer nr_mer nfci_ppp nfli_ppp nfts_ppp nr_ppp /*ndp_mer_ppp_pc_ratio*/


*Export to excel
export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataT12", modify) cell(A4) keepcellfmt


