

**# Figure 3a
/*------------------------------------------------------------------------------
Figure 3a. Net Foreign Wealth as % National Income (MER) by World Region 1970-2023
------------------------------------------------------------------------------*/
*Import data
use main_dataset.dta,clear
keep if year>=1970
drop if country=="WO"

preserve
*Aggregate at the national-year level
collapse (sum) nfw_mer_usd nni_mer_usd, by(year )
g nfw_mer_ratioWorld=nfw_mer_usd/nni_mer_usd
drop nfw_mer_usd nni_mer_usd
save nfw_mer_ratioWorld.dta,replace
restore 

*Aggregate at the region-year level
collapse (sum) nfw_mer_usd nni_mer_usd, by(year region)

*Format in Figure format
g nfw_mer_ratio=nfw_mer_usd/nni_mer_usd
drop nfw_mer_usd nni_mer_usd
reshape wide nfw_mer_ratio , i(year) j(region) string
merge 1:1 year using nfw_mer_ratioWorld.dta
drop _merge 
cap erase nfw_mer_ratioWorld.dta

tsset year
tsline nfw_mer_ratioEASA nfw_mer_ratioEURO nfw_mer_ratioLATA nfw_mer_ratioMENA nfw_mer_ratioNAOC nfw_mer_ratioRUCA nfw_mer_ratioSSAF nfw_mer_ratioSSEA nfw_mer_ratioWorld

*Export 
export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataF3", modify) cell(A4) keepcellfmt







**# Figure 3b 
/*------------------------------------------------------------------------------
Figure 3b. Net Foreign Wealth as % National Income (MER) for the Largest Economies 1970-2023
------------------------------------------------------------------------------*/
*Import data
use main_dataset.dta,clear
keep if year>=1970
drop if country=="WO"

preserve
*Aggregate at the national-year level
collapse (sum) nfw_mer_usd nni_mer_usd, by(year )
g nfw_mer_ratioWorld=nfw_mer_usd/nni_mer_usd
drop nfw_mer_usd nni_mer_usd
save nfw_mer_ratioWorld.dta,replace
restore 

merge m:1 country using largest.dta
keep if _merge==3
drop _merge
loc s countryname
		replace `s' = subinstr(`s', " ", "_", .)

*Aggregate at the region-year level
collapse (sum) nfw_mer_usd nni_mer_usd, by(year countryname)

*Format in Figure format
g nfw_mer_ratio=nfw_mer_usd/nni_mer_usd
drop nfw_mer_usd nni_mer_usd
reshape wide nfw_mer_ratio , i(year) j(countryname) string
merge 1:1 year using nfw_mer_ratioWorld.dta
drop _merge 
cap erase nfw_mer_ratioWorld.dta

ren nfw_mer_ratio* *

foreach var of varlist _all {
	label var `var' ""
}
 
tsset year
tsline Brazil China France Germany India Indonesia Japan Russian_Federation USA United_Kingdom World, title("Net foreign wealth as % national income (MER)" "by country 1970-2023" "in current USD") note("Positive value: A significant portion of the country's wealth comes from foreign investments (difference between" "a country's foreign assets and its foreign liabilities).") lpattern(dash dash dash dash shortdash shortdash shortdash shortdash  ) legend(size(small) row(2)) lcolor(green red  blue cyan magenta gold orange purple brown pink black) 

*Export 
export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataF3_large", modify) cell(A4) keepcellfmt




**# Figure 4a
/*------------------------------------------------------------------------------
Figure 4a. Net Foreign Wealth as % National Income (PPP) by World Region 1970-2023
------------------------------------------------------------------------------*/
*Import data
use main_dataset.dta,clear
keep if year>=1970
drop if country=="WO"

preserve
*Aggregate at the national-year level
collapse (sum) nfw_ppp_2023_usd nni_ppp_2023_usd, by(year )
g nfw_ppp_ratioWorld=nfw_ppp_2023_usd/nni_ppp_2023_usd
drop nfw_ppp_2023_usd nni_ppp_2023_usd
save nfw_ppp_ratioWorld.dta,replace
restore 

*Aggregate at the region-year level
collapse (sum) nfw_ppp_2023_usd nni_ppp_2023_usd, by(year region)

*Format in Figure format
g nfw_ppp_2023_ratio=nfw_ppp_2023_usd/nni_ppp_2023_usd
drop nfw_ppp_2023_usd nni_ppp_2023_usd
reshape wide nfw_ppp_2023_ratio , i(year) j(region) string
merge 1:1 year using nfw_ppp_ratioWorld.dta
drop _merge 
cap erase nfw_ppp_ratioWorld.dta

tsset year
ren nfw_ppp_2023_ratio* *
tsline EASA EURO LATA MENA NAOC RUCA SSAF SSEA nfw_ppp_ratioWorld

*Export 
export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataF4", modify) cell(A4) keepcellfmt






**# Figure 4b
/*------------------------------------------------------------------------------
Figure 4b. Net Foreign Wealth as % National Income (PPP) for the Largest Economies 1970-2023
------------------------------------------------------------------------------*/
*Import data
use main_dataset.dta,clear
keep if year>=1970
drop if country=="WO"

preserve
*Aggregate at the national-year level
collapse (sum) nfw_ppp_2023_usd nni_ppp_2023_usd, by(year )
g nfw_ppp_ratioWorld=nfw_ppp_2023_usd/nni_ppp_2023_usd
drop nfw_ppp_2023_usd nni_ppp_2023_usd
save nfw_ppp_ratioWorld.dta,replace
restore 

merge m:1 country using largest.dta
keep if _merge==3
drop _merge
loc s countryname
		replace `s' = subinstr(`s', " ", "_", .)

*Aggregate at the region-year level
collapse (sum) nfw_ppp_2023_usd nni_ppp_2023_usd, by(year countryname)

*Format in Figure format
g nfw_ppp_ratio=nfw_ppp_2023_usd/nni_ppp_2023_usd
drop nfw_ppp_2023_usd nni_ppp_2023_usd
reshape wide nfw_ppp_ratio , i(year) j(countryname) string
merge 1:1 year using nfw_ppp_ratioWorld.dta
drop _merge 
cap erase nfw_ppp_ratioWorld.dta

ren nfw_ppp_ratio* *

foreach var of varlist _all {
	label var `var' ""
}
 
tsset year
tsline Brazil China France Germany India Indonesia Japan Russian_Federation USA United_Kingdom World, title("Net foreign wealth as % national income (PPP)" "by country 1970-2023" "in current USD") note("Positive value: A significant portion of the country's wealth comes from foreign investments (difference between" "a country's foreign assets and its foreign liabilities).") lpattern(dash dash dash dash shortdash shortdash shortdash shortdash  ) legend(size(small) row(2)) lcolor(green red  blue cyan magenta gold orange purple brown pink black) 

*Export 
export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataF4_large", modify) cell(A4) keepcellfmt





**# Figure 5a 
/*------------------------------------------------------------------------------
Figure 5a. Net Foreign Income as % Net Domestic Product (MER) by World Region 1970-2023
------------------------------------------------------------------------------*/
*Import data 
use main_dataset.dta,clear
keep if year>=1970
drop if country=="WO"

preserve
*Aggregate at the national-year level
collapse (sum) ndp_mer_usd nfi_mer_usd, by(year )
g nfi_mer_ratioWorld=nfi_mer_usd/ndp_mer_usd
drop ndp_mer_usd nfi_mer_usd
save nfi_mer_ratioWorld.dta,replace
restore 

*Aggregate at the region-year level
collapse (sum) ndp_mer_usd nfi_mer_usd, by(year region)

*Format in Figure format
g nfi_mer_ratio=nfi_mer_usd/ndp_mer_usd
drop ndp_mer_usd nfi_mer_usd
reshape wide nfi_mer_ratio , i(year) j(region) string
merge 1:1 year using nfi_mer_ratioWorld.dta
drop _merge 
cap erase nfi_mer_ratioWorld.dta

tsset year
tsline nfi_mer_ratioEASA nfi_mer_ratioEURO nfi_mer_ratioLATA nfi_mer_ratioMENA nfi_mer_ratioNAOC nfi_mer_ratioRUCA nfi_mer_ratioSSAF nfi_mer_ratioSSEA nfi_mer_ratioWorld,yline(0,lcolor(gray)) xla(1970(2)2023,angle(90) labsize(small)) ///
lcolor(red ebblue green gold magenta orange sienna purple black) lwidth(thick thick thick thick thick thick thick thick thick) legend(row(2))

*Export 
export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataF5", modify) cell(A4) keepcellfmt





**# Figure 5b
/*------------------------------------------------------------------------------
Figure 5b. Net Foreign Income as % Net Domestic Product (MER) for the Largest Economies 1970-2023
------------------------------------------------------------------------------*/

*Import data (start here)
use main_dataset.dta,clear
keep if year>=1970
drop if country=="WO"

preserve
*Aggregate at the national-year level
collapse (sum) ndp_mer_usd nfi_mer_usd, by(year )
g nfi_mer_ratioWorld=nfi_mer_usd/ndp_mer_usd
drop ndp_mer_usd nfi_mer_usd
save nfi_mer_ratioWorld.dta,replace
restore 

merge m:1 country using largest.dta
keep if _merge==3
drop _merge
loc s countryname
		replace `s' = subinstr(`s', " ", "_", .)

*Aggregate at the region-year level
collapse (sum) ndp_mer_usd nfi_mer_usd, by(year countryname)

*Format in Figure format
g nfi_mer_ratio=nfi_mer_usd/ndp_mer_usd
drop ndp_mer_usd nfi_mer_usd
reshape wide nfi_mer_ratio , i(year) j(countryname) string
merge 1:1 year using nfi_mer_ratioWorld.dta
drop _merge 
cap erase nfi_mer_ratioWorld.dta

ren nfi_mer_ratio* *

foreach var of varlist _all {
	label var `var' ""
}
 
tsset year
tsline Brazil China France Germany India Indonesia Japan Russian_Federation USA United_Kingdom World, title("Net foreign income as % net domestic product (MER)" "by country 1970-2023" "in current USD") note("Positive value: The country earns more from abroad than foreigners earn within it.") lpattern(dash dash dash dash shortdash shortdash shortdash shortdash  ) legend(size(small) row(2)) lcolor(green red  blue cyan magenta gold orange purple brown pink black) 

*Export 
export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataF5_large", modify) cell(A4) keepcellfmt




**# Figures 5c and 5e 
/*------------------------------------------------------------------------------
Figure 5c. Net Foreign Capital Income as % Net Domestic Product (MER) by World Region 1970-2023

Figure 5e. Net Foreign Labor Income as % Net Domestic Product (MER) by World Region 1970-2023
------------------------------------------------------------------------------*/
foreach var in nfci nfli{


*Use the WID
	use main_dataset.dta,clear
	g `var'_mer_usd=(nipi*`var')/mer_usd
	keep if year>=1970
	drop if country=="WO"
	preserve
	*Aggregate at the national-year level
	collapse (sum) ndp_mer_usd `var'_mer_usd, by(year )
	g `var'_mer_ratioWorld=`var'_mer_usd/ndp_mer_usd
	drop ndp_mer_usd `var'_mer_usd
	save `var'_mer_ratioWorld.dta,replace
	restore 
	*Aggregate at the region-year level
	collapse (sum) ndp_mer_usd `var'_mer_usd, by(year region)
	*Format in Figure format
	g `var'_mer_ratio=`var'_mer_usd/ndp_mer_usd
	drop ndp_mer_usd `var'_mer_usd
	reshape wide `var'_mer_ratio , i(year) j(region) string
	merge 1:1 year using `var'_mer_ratioWorld.dta
	drop _merge 
	cap erase `var'_mer_ratioWorld.dta
	tsset year
	tsline `var'_mer_ratioEASA `var'_mer_ratioEURO `var'_mer_ratioLATA `var'_mer_ratioMENA `var'_mer_ratioNAOC `var'_mer_ratioRUCA `var'_mer_ratioSSAF `var'_mer_ratioSSEA `var'_mer_ratioWorld,yline(0,lcolor(gray)) xla(1970(2)2023,angle(90) labsize(small)) ///
	lcolor(red ebblue green gold magenta orange sienna purple black) lwidth(thick thick thick thick thick thick thick thick thick) legend(row(2))
	export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataF5_`var'", modify) cell(A4) keepcellfmt
}




**# Figure 5d
/*------------------------------------------------------------------------------
Figure 5d. Net Foreign Capital Income as % Net Domestic Product (MER) for the Largest Economies 1970-2023
------------------------------------------------------------------------------*/

	use main_dataset.dta,clear
	g nfci_mer_usd=(nipi*nfci)/mer_usd
	keep if year>=1970
	drop if country=="WO"

	preserve
	*Aggregate at the national-year level
	collapse (sum) ndp_mer_usd nfci_mer_usd, by(year )
	g nfci_mer_ratioWorld=nfci_mer_usd/ndp_mer_usd
	drop ndp_mer_usd nfci_mer_usd
	save nfci_mer_ratioWorld.dta,replace
	restore 

	merge m:1 country using largest.dta
	keep if _merge==3
	drop _merge
	loc s countryname
			replace `s' = subinstr(`s', " ", "_", .)

	*Aggregate at the region-year level
	collapse (sum) ndp_mer_usd nfci_mer_usd, by(year countryname)

	*Format in Figure format
	g nfci_mer_ratio=nfci_mer_usd/ndp_mer_usd
	drop ndp_mer_usd nfci_mer_usd
	reshape wide nfci_mer_ratio , i(year) j(countryname) string
	merge 1:1 year using nfci_mer_ratioWorld.dta
	drop _merge 
	cap erase nfci_mer_ratioWorld.dta

	ren nfci_mer_ratio* *

	foreach var of varlist _all {
		label var `var' ""
	}
	 
	tsset year
	tsline Brazil China France Germany India Indonesia Japan Russian_Federation USA United_Kingdom World, title("Net foreign capital income as % net domestic product (MER)" "by country 1970-2023" "in current USD") note("Positive value: The country earns more from abroad than foreigners earn within it.") lpattern(dash dash dash dash shortdash shortdash shortdash shortdash  ) legend(size(small) row(2)) lcolor(green red  blue cyan magenta gold orange purple brown pink black) 


	*Export 
	export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataF5_large_nfci", modify) cell(A4) keepcellfmt

	
**# Figure 5f
/*------------------------------------------------------------------------------
Figure 5f. Net Foreign Labor Income as % Net Domestic Product (MER) for the Largest Economies 1970-2023
------------------------------------------------------------------------------*/	

	use main_dataset.dta,clear
	g nfli_mer_usd=(nipi*nfli)/mer_usd
	keep if year>=1970
	drop if country=="WO"

	preserve
	*Aggregate at the national-year level
	collapse (sum) ndp_mer_usd nfli_mer_usd, by(year )
	g nfli_mer_ratioWorld=nfli_mer_usd/ndp_mer_usd
	drop ndp_mer_usd nfli_mer_usd
	save nfli_mer_ratioWorld.dta,replace
	restore 

	merge m:1 country using largest.dta
	keep if _merge==3
	drop _merge
	loc s countryname
			replace `s' = subinstr(`s', " ", "_", .)

	*Aggregate at the region-year level
	collapse (sum) ndp_mer_usd nfli_mer_usd, by(year countryname)

	*Format in Figure format
	g nfli_mer_ratio=nfli_mer_usd/ndp_mer_usd
	drop ndp_mer_usd nfli_mer_usd
	reshape wide nfli_mer_ratio , i(year) j(countryname) string
	merge 1:1 year using nfli_mer_ratioWorld.dta
	drop _merge 
	cap erase nfli_mer_ratioWorld.dta

	ren nfli_mer_ratio* *

	foreach var of varlist _all {
		label var `var' ""
	}
	 
	tsset year
	tsline Brazil China France Germany India Indonesia Japan Russian_Federation USA United_Kingdom World, title("Net foreign capital income as % net domestic product (MER)" "by country 1970-2023" "in current USD") note("Positive value: The country earns more from abroad than foreigners earn within it.") lpattern(dash dash dash dash shortdash shortdash shortdash shortdash  ) legend(size(small) row(2)) lcolor(green red  blue cyan magenta gold orange purple brown pink black) 

	*Export 
	export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataF5_large_nfli", modify) cell(A4) keepcellfmt
	
	
	

**# Figures 5g 
/*------------------------------------------------------------------------------
Figure 5g. Net Foreign Taxes and Subsidies as % Net Domestic Product (MER) by World Region 1970-2023

------------------------------------------------------------------------------*/

foreach var in nfts {
*Use the RAW data shared by Gaston if the WID is not updated

*Use the WID if it is updated (start here)
	use main_dataset.dta,clear
	g `var'_mer_usd=(nipi*`var')/mer_usd
	keep if year>=1970
	drop if country=="WO"
	preserve
	*Aggregate at the national-year level
	collapse (sum) ndp_mer_usd `var'_mer_usd, by(year )
	g `var'_mer_ratioWorld=`var'_mer_usd/ndp_mer_usd
	drop ndp_mer_usd `var'_mer_usd
	save `var'_mer_ratioWorld.dta,replace
	restore 
	*Aggregate at the region-year level
	collapse (sum) ndp_mer_usd `var'_mer_usd, by(year region)
	*Format in Figure format
	g `var'_mer_ratio=`var'_mer_usd/ndp_mer_usd
	drop ndp_mer_usd `var'_mer_usd
	reshape wide `var'_mer_ratio , i(year) j(region) string
	merge 1:1 year using `var'_mer_ratioWorld.dta
	drop _merge 
	cap erase `var'_mer_ratioWorld.dta
	tsset year
	tsline `var'_mer_ratioEASA `var'_mer_ratioEURO `var'_mer_ratioLATA `var'_mer_ratioMENA `var'_mer_ratioNAOC `var'_mer_ratioRUCA `var'_mer_ratioSSAF `var'_mer_ratioSSEA `var'_mer_ratioWorld,yline(0,lcolor(gray)) xla(1970(2)2023,angle(90) labsize(small)) ///
	lcolor(red ebblue green gold magenta orange sienna purple black) lwidth(thick thick thick thick thick thick thick thick thick) legend(row(2))
	export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataF5_`var'", modify) cell(A4) keepcellfmt
}


	
	
	

**# Figure 5h
/*------------------------------------------------------------------------------
Figure 5h. Net Foreign Taxes and Subsidies as % Net Domestic Product (MER) for the Largest Economies 1970-2023
------------------------------------------------------------------------------*/	


	use main_dataset.dta,clear
	g nfts_mer_usd=(nipi*nfts)/mer_usd
	keep if year>=1970
	drop if country=="WO"

	preserve
	*Aggregate at the national-year level
	collapse (sum) ndp_mer_usd nfts_mer_usd, by(year )
	g nfts_mer_ratioWorld=nfts_mer_usd/ndp_mer_usd
	drop ndp_mer_usd nfts_mer_usd
	save nfts_mer_ratioWorld.dta,replace
	restore 

	merge m:1 country using largest.dta
	keep if _merge==3
	drop _merge
	loc s countryname
			replace `s' = subinstr(`s', " ", "_", .)

	*Aggregate at the region-year level
	collapse (sum) ndp_mer_usd nfts_mer_usd, by(year countryname)

	*Format in Figure format
	g nfts_mer_ratio=nfts_mer_usd/ndp_mer_usd
	drop ndp_mer_usd nfts_mer_usd
	reshape wide nfts_mer_ratio , i(year) j(countryname) string
	merge 1:1 year using nfts_mer_ratioWorld.dta
	drop _merge 
	cap erase nfts_mer_ratioWorld.dta

	ren nfts_mer_ratio* *

	foreach var of varlist _all {
		label var `var' ""
	}
	 
	tsset year
	tsline Brazil China France Germany India Indonesia Japan Russian_Federation USA United_Kingdom World, title("Net foreign taxes and subsidies as % net domestic product (MER)" "by country 1970-2023" "in current USD") note("Positive value: The country earns more from abroad than foreigners earn within it.") lpattern(dash dash dash dash shortdash shortdash shortdash shortdash  ) legend(size(small) row(2)) lcolor(green red  blue cyan magenta gold orange purple brown pink black) 

	*Export 
	export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataF5_large_nfts", modify) cell(A4) keepcellfmt	
	

	


	




**# Figure 6a
/*------------------------------------------------------------------------------
Figure 6a. Net Foreign Income as % Net Domestic Product (PPP) by World Region 1970-2023
------------------------------------------------------------------------------*/

*Import data
use main_dataset.dta,clear

keep if year>=1970
drop if country=="WO"

preserve
*Aggregate at the national-year level
collapse (sum) ndp_ppp_2023_usd nfi_ppp_2023_usd, by(year )
g nfi_ppp_ratioWorld=nfi_ppp_2023_usd/ndp_ppp_2023_usd
drop ndp_ppp_2023_usd nfi_ppp_2023_usd
save nfi_ppp_ratioWorld.dta,replace
restore 

*Aggregate at the region-year level
collapse (sum) ndp_ppp_2023_usd nfi_ppp_2023_usd, by(year region)

*Format in Figure format
g nfi_ppp_ratio=nfi_ppp_2023_usd/ndp_ppp_2023_usd
drop ndp_ppp_2023_usd nfi_ppp_2023_usd
reshape wide nfi_ppp_ratio , i(year) j(region) string
merge 1:1 year using nfi_ppp_ratioWorld.dta
drop _merge 
cap erase nfi_ppp_ratioWorld.dta

tsset year
tsline nfi_ppp_ratioEASA nfi_ppp_ratioEURO nfi_ppp_ratioLATA nfi_ppp_ratioMENA nfi_ppp_ratioNAOC nfi_ppp_ratioRUCA nfi_ppp_ratioSSAF nfi_ppp_ratioSSEA nfi_ppp_ratioWorld

*Export 
export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataF6", modify) cell(A4) keepcellfmt






**# Figure 6b
/*------------------------------------------------------------------------------
Figure 6b. Net Foreign Income as % Net Domestic Product (PPP) for the Largest Economies 1970-2023
------------------------------------------------------------------------------*/

*Import data
use main_dataset.dta,clear
keep if year>=1970
drop if country=="WO"

preserve
*Aggregate at the national-year level
collapse (sum) ndp_ppp_2023_usd nfi_ppp_2023_usd, by(year )
g nfi_ppp_ratioWorld=nfi_ppp_2023_usd/ndp_ppp_2023_usd
drop ndp_ppp_2023_usd nfi_ppp_2023_usd
save nfi_ppp_ratioWorld.dta,replace
restore 

merge m:1 country using largest.dta
keep if _merge==3
drop _merge
loc s countryname
		replace `s' = subinstr(`s', " ", "_", .)

*Aggregate at the region-year level
collapse (sum) ndp_ppp_2023_usd nfi_ppp_2023_usd, by(year countryname)

*Format in Figure format
g nfi_ppp_ratio=nfi_ppp_2023_usd/ndp_ppp_2023_usd
drop ndp_ppp_2023_usd nfi_ppp_2023_usd
reshape wide nfi_ppp_ratio , i(year) j(countryname) string
merge 1:1 year using nfi_ppp_ratioWorld.dta
drop _merge 
cap erase nfi_ppp_ratioWorld.dta

ren nfi_ppp_ratio* *

foreach var of varlist _all {
	label var `var' ""
}
 
tsset year
tsline Brazil China France Germany India Indonesia Japan Russian_Federation USA United_Kingdom World, title("Net foreign income as % net domestic product (PPP)" "by country 1970-2023" "in current USD") note("Positive value: The country earns more from abroad than foreigners earn within it.") lpattern(dash dash dash dash shortdash shortdash shortdash shortdash  ) legend(size(small) row(2)) lcolor(green red  blue cyan magenta gold orange purple brown pink black) 

*Export 
export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataF6_large", modify) cell(A4) keepcellfmt






**# Table 13
/*------------------------------------------------------------------------------
Table 13. Per Capita National Income and Trade Balance (2023)
------------------------------------------------------------------------------*/

*Import data
use main_dataset.dta,clear
keep if year==2023
drop if country=="WO"
drop nni_mer_usd  nni_ppp_2023_usd
*Generate relevant variables
foreach var in nni tb exp imp{
	g `var'_ppp=`var'/ppp_2023_eur
	g `var'_mer=`var'/mer_eur
	g `var'_ppp_pc=`var'_ppp/poptot
	g `var'_mer_pc=`var'_mer/poptot
}



 *Sort from lowest to highest per capita national income (PPP)
 sort nni_ppp_pc
 
 *Classify according to per capita net national income
 egen seq=seq()
 g percentile=""
 replace percentile="0%-10%" if inrange(seq,1,22)
 replace percentile="10%-20%" if inrange(seq,23,44)
 replace percentile="20%-30%" if inrange(seq,45,66)
 replace percentile="30%-40%" if inrange(seq,67,87)
 replace percentile="40%-50%" if inrange(seq,88,108) 
 replace percentile="50%-60%" if inrange(seq,109,129)
 replace percentile="60%-70%" if inrange(seq,130,150)
 replace percentile="70%-80%" if inrange(seq,151,172)
 replace percentile="80%-90%" if inrange(seq,173,194)
 replace percentile="90%-100%" if inrange(seq,195,216) 
 
 
 *Compute for World 
preserve
	collapse (sum) poptot  nni_ppp nni_mer tb_ppp tb_mer exp_ppp exp_mer imp_ppp imp_mer   	
	sum poptot
	loc poptot=r(mean)
	foreach var in nni {
		sum `var'_ppp
		loc nni_ppp=r(mean)
		loc `var'_ppp_pc= `nni_ppp'/`poptot'
		sum `var'_mer
		loc nni_mer=r(mean)
		loc `var'_mer_pc=`nni_mer'/`poptot'
	}
	foreach var in tb exp imp{
		sum `var'_ppp
		loc `var'_ppp_ratio=r(mean)/`nni_ppp'
		sum `var'_mer
		loc `var'_mer_ratio= r(mean)/`nni_mer'
	}
	loc nni_pc_ratio=`nni_mer_pc'/`nni_ppp_pc'
	
	sum nni_mer 
	loc nni_mer=r(mean)
	sum nni_ppp
	loc nni_ppp=r(mean)
	
	loc nni_ratio=`nni_mer'/`nni_ppp'
restore

 *Compute per percentile
 collapse (sum) poptot nni_ppp nni_mer tb_ppp tb_mer exp_ppp exp_mer imp_ppp imp_mer 				,by(percentile)
 
foreach var in nni {
	g `var'_ppp_pc=`var'_ppp/poptot
	g `var'_mer_pc= `var'_mer/poptot
}

foreach var in tb exp imp{
	g `var'_ppp_ratio=`var'_ppp/nni_ppp
	g `var'_mer_ratio= `var'_mer/nni_mer
}
g nni_pc_ratio=nni_mer_pc/nni_ppp_pc
g nni_ratio=nni_mer/nni_ppp
 
*Include World 
set obs `=_N+1'
	replace percentile="World" if percentile==""
	foreach var in nni {
		replace `var'_ppp_pc=``var'_ppp_pc' if percentile=="World" & `var'_ppp_pc==.
		replace `var'_mer_pc=``var'_mer_pc' if percentile=="World" & `var'_mer_pc==.		
	}
	foreach var in tb exp imp{
		replace `var'_ppp_ratio=``var'_ppp_ratio' if percentile=="World" & `var'_ppp_ratio==.
		replace `var'_mer_ratio=``var'_mer_ratio' if percentile=="World" & `var'_mer_ratio==.
	}
	replace nni_pc_ratio=`nni_pc_ratio' if percentile=="World" & nni_pc_ratio==.
	replace nni_ratio=`nni_ratio' if percentile=="World" & nni_ratio==.	
	
*Format for exporting	
order percentile nni_ppp_pc exp_ppp_ratio imp_ppp_ratio tb_ppp_ratio nni_mer_pc nni_ratio exp_mer_ratio imp_mer_ratio tb_mer_ratio
drop poptot nni_ppp nni_mer tb_ppp tb_mer exp_ppp exp_mer imp_ppp imp_mer 


*Export to excel
export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataT13", modify) cell(A4) keepcellfmt





**# Figure 7a
/*------------------------------------------------------------------------------
Figure 7a. Net Trade Balance as % National Income (MER) by World Region 1970-2023
------------------------------------------------------------------------------*/
*Import data
use main_dataset.dta,clear
keep if year>=1970
drop if country=="WO"

*Generate relevant variables
foreach var in nni tb exp imp{
	g `var'_mer=(nipi*`var')/mer_usd
}

preserve
*Aggregate at the national-year level
collapse (sum) tb_mer nni_mer, by(year )
g tb_mer_ratioWorld=tb_mer/nni_mer
drop tb_mer nni_mer
save tb_mer_ratioWorld.dta,replace
restore 

*Aggregate at the region-year level
collapse (sum) tb_mer nni_mer, by(year region)

*Format in Figure format
g tb_mer_ratio=tb_mer/nni_mer
drop tb_mer nni_mer
reshape wide tb_mer_ratio , i(year) j(region) string
merge 1:1 year using tb_mer_ratioWorld.dta
drop _merge 
cap erase tb_mer_ratioWorld.dta

tsset year
tsline tb_mer_ratioEASA tb_mer_ratioEURO tb_mer_ratioLATA tb_mer_ratioMENA tb_mer_ratioNAOC tb_mer_ratioRUCA tb_mer_ratioSSAF tb_mer_ratioSSEA tb_mer_ratioWorld

*Export 
export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataF7", modify) cell(A4) keepcellfmt





**# Figures 7b and 7c 
/*------------------------------------------------------------------------------
Figure 7b. Net Trade Balance (Goods) as % National Income (MER) by World Region 1970-2023

Figure 7c. Net Trade Balance (Services) as % National Income (MER) by World Region 1970-2023
------------------------------------------------------------------------------*/
/*
This next code considers raw data (14-oct-2024), It is necesarry to change the code when the WID is updated and the goods and services variables are included in the dataset

//Already in the WID:
// tbxrx = exports (goods + services)
// tbmpx = imports (goods + services)
// tbnnx = trade balance

//Missingg in the WID:
// tgxrx = exports goods
// tgmpx = imports goods
// tgnnx = trade balance goods
// tsxrx = exports services
// tsmpx = imports services
// tsnnx = trade balance services
*/
use "$root\raw-data\\merge-historical-aggregates.dta",clear


keep if inlist(widcode,"mtbxrx999i", "mtbmpx999i", "mtbnnx999i", "mtgxrx999i" ,"mtgmpx999i" ,"mtgnnx999i") | ///
		inlist(widcode, "mtsxrx999i", "mtsmpx999i", "mtsnnx999i", "xlcusx999i","inyixx999i","mnninc999i")
ren iso country
gen corecountry=.
foreach c of global corecountries {
	replace corecountry=1 if country=="`c'"
	}
keep if (corecountry==1 | country=="WO")
keep year country value widcode
format value %30.10f
reshape wide value ,i(year country) j(widcode) string 
ren value* *
ren *999i *


*Generate relevant variables
foreach var in mtbxrx mtbmpx mtbnnx   	mtgxrx mtgmpx mtgnnx  	mtsxrx mtsmpx mtsnnx mnninc{
	g `var'_mer=((inyixx*`var')/xlcusx)/1000
}



*Generate Region variable
 gen region2=""
foreach c of global EURO {
	replace region2="EURO" if country=="`c'"
	}
foreach c of global NAOC {
	replace region2="NAOC" if country=="`c'"
	}
foreach c of global LATA {
	replace region2="LATA" if country=="`c'"
	}
foreach c of global MENA {
	replace region2="MENA" if country=="`c'"
	}
foreach c of global SSAF {
	replace region2="SSAF" if country=="`c'"
	}
foreach c of global RUCA {
	replace region2="RUCA" if country=="`c'"
	}
foreach c of global EASA {
	replace region2="EASA" if country=="`c'"
	}	
foreach c of global SSEA {
	replace region2="SSEA" if country=="`c'"
	}		
ren region2 region

replace region="World" if country=="WO"
// use main_dataset.dta,clear
keep if year>=1970
drop if country=="WO"




preserve
*Aggregate at the national-year level
collapse (sum) mtbnnx_mer mnninc_mer, by(year )
g tb_mer_ratioWorld=mtbnnx_mer/mnninc_mer
drop mtbnnx_mer mnninc_mer
save tb_mer_ratioWorld.dta,replace
restore 

preserve
*Aggregate at the region-year level
collapse (sum) mtbnnx_mer mnninc_mer, by(year region)


*Format in Figure format
g tb_mer_ratio=mtbnnx_mer/mnninc_mer
drop mtbnnx_mer mnninc_mer
reshape wide tb_mer_ratio , i(year) j(region) string
merge 1:1 year using tb_mer_ratioWorld.dta
drop _merge 
cap erase tb_mer_ratioWorld.dta

tsset year
ren tb_mer_ratio* *
 foreach var of varlist _all {
	label var `var' ""
}
tsline EASA EURO LATA MENA NAOC RUCA SSAF SSEA World, title("Trade Balance (G&S)" "% of National Income (MER)")  ///
lcolor(red ebblue green gold magenta orange sienna purple black) legend(row(2))
restore


*****Goods

preserve
*Aggregate at the national-year level
collapse (sum) mtgnnx_mer mnninc_mer, by(year )
g tb_mer_ratioWorld=mtgnnx_mer/mnninc_mer
drop mtgnnx_mer mnninc_mer
save tb_mer_ratioWorld.dta,replace
restore 



preserve
*Aggregate at the region-year level
collapse (sum) mtgnnx_mer mnninc_mer, by(year region)

*Format in Figure format
g tb_mer_ratio=mtgnnx_mer/mnninc_mer
drop mtgnnx_mer mnninc_mer
reshape wide tb_mer_ratio , i(year) j(region) string
merge 1:1 year using tb_mer_ratioWorld.dta
drop _merge 
cap erase tb_mer_ratioWorld.dta

tsset year
ren tb_mer_ratio* *
 foreach var of varlist _all {
	label var `var' ""
}
tsline EASA EURO LATA MENA NAOC RUCA SSAF SSEA World, title("Trade Balance (G)" "% of National Income (MER)")  ///
lcolor(red ebblue green gold magenta orange sienna purple black) legend(row(2))

keep year EASA EURO LATA MENA NAOC RUCA SSAF SSEA World
order year EASA EURO LATA MENA NAOC RUCA SSAF SSEA World
*Export 
export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataF7b", modify) cell(A4) keepcellfmt
restore


*****Services

preserve
*Aggregate at the national-year level
collapse (sum) mtsnnx_mer mnninc_mer, by(year )
g tb_mer_ratioWorld=mtsnnx_mer/mnninc_mer
drop mtsnnx_mer mnninc_mer
save tb_mer_ratioWorld.dta,replace
restore 



preserve
*Aggregate at the region-year level
collapse (sum) mtsnnx_mer mnninc_mer, by(year region)

*Format in Figure format
g tb_mer_ratio=mtsnnx_mer/mnninc_mer
drop mtsnnx_mer mnninc_mer
reshape wide tb_mer_ratio , i(year) j(region) string
merge 1:1 year using tb_mer_ratioWorld.dta
drop _merge 
cap erase tb_mer_ratioWorld.dta

tsset year
ren tb_mer_ratio* *
 foreach var of varlist _all {
	label var `var' ""
}
tsline EASA EURO LATA MENA NAOC RUCA SSAF SSEA World, title("Trade Balance (S)" "% of National Income (MER)")  ///
lcolor(red ebblue green gold magenta orange sienna purple black) legend(row(2))

keep year EASA EURO LATA MENA NAOC RUCA SSAF SSEA World
order year EASA EURO LATA MENA NAOC RUCA SSAF SSEA World
*Export 
export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataF7c", modify) cell(A4) keepcellfmt
restore








**# Figure 7d
/*------------------------------------------------------------------------------
Figure 7d. Net Trade Balance as % World Income (MER) by World Region 1970-2023
------------------------------------------------------------------------------*/
*Import data
use main_dataset.dta,clear
keep if year>=1970
 drop if country=="WO"

*Generate relevant variables
foreach var in nni tb exp imp{
	g `var'_mer=(nipi*`var')/mer_usd
}


preserve
*Aggregate at the national-year level
drop if country=="WO"
collapse (sum)  nni_mer tb_mer, by(year )
ren nni_mer nni_mer_world
ren tb_mer tb_mer_world
save nni_mer_World.dta,replace
restore 

*Aggregate at the region-year level
collapse (sum) tb_mer nni_mer, by(year region)

merge m:1 year using nni_mer_World.dta
keep if _merge==3
drop _merge
cap erase nni_mer_World.dta
g tb_mer_world_ratio=tb_mer/nni_mer_world
g tb_mer_world_ratio_world=tb_mer_world/nni_mer_world

drop tb_mer nni_mer nni_mer_world tb_mer_world
*Format in Figure format
reshape wide tb_mer_world_ratio tb_mer_world_ratio_world, i(year) j(region) string


ren tb_mer_world_ratio* *
keep year EASA EURO LATA MENA NAOC RUCA SSAF SSEA _worldEASA
ren _worldEASA World

tsset year
tsline EASA EURO LATA MENA NAOC RUCA SSAF SSEA World
order year EASA EURO LATA MENA NAOC RUCA SSAF SSEA World
*Export 
export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataF7d", modify) cell(A4) keepcellfmt









**# Figure 7e
/*------------------------------------------------------------------------------
Figure 7e. Net Trade Balance as % National Income (MER) for the Largest Economies 1970-2023
------------------------------------------------------------------------------*/
*Import data
use main_dataset.dta,clear
keep if year>=1970
drop if country=="WO"

*Generate relevant variables
foreach var in nni tb exp imp{
	g `var'_mer=(nipi*`var')/mer_usd
}

preserve
*Aggregate at the national-year level
collapse (sum) tb_mer nni_mer, by(year )
g tb_mer_ratioWorld=tb_mer/nni_mer
drop tb_mer nni_mer
save tb_mer_ratioWorld.dta,replace
restore 

merge m:1 country using largest.dta
keep if _merge==3
drop _merge
loc s countryname
		replace `s' = subinstr(`s', " ", "_", .)

*Aggregate at the region-year level
collapse (sum) tb_mer nni_mer, by(year countryname)

*Format in Figure format
g tb_mer_ratio=tb_mer/nni_mer
drop tb_mer nni_mer
reshape wide tb_mer_ratio , i(year) j(countryname) string
merge 1:1 year using tb_mer_ratioWorld.dta
drop _merge 
cap erase tb_mer_ratioWorld.dta

ren tb_mer_ratio* *

foreach var of varlist _all {
	label var `var' ""
}
 
tsset year
tsline Brazil China France Germany India Indonesia Japan Russian_Federation USA United_Kingdom World, title("Net trade balance as % national income (MER)" "by country 1970-2023" "in current USD") note("Positive value: Trade surplus, meaning exports exceed imports. The larger the absolute value " "of the percentage, the more significant the trade imbalance is relative to the size of the economy.") lpattern(dash dash dash dash shortdash shortdash shortdash shortdash  ) legend(size(small) row(2)) lcolor(green red  blue cyan magenta gold orange purple brown pink black) 

*Export 
export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataF7_large", modify) cell(A4) keepcellfmt





**# Figure 7f
/*------------------------------------------------------------------------------
Figure 7f. Net Trade Balance (Goods) as % National Income (MER) for the Largest Economies 1970-2023
------------------------------------------------------------------------------*/
/*
This next code considers raw data (14-oct-2024) shared by Gaston, It is necesarry to change the code when the WID is updated and the goods and services variables are included in the dataset

//Already in the WID:
// tbxrx = exports (goods + services)
// tbmpx = imports (goods + services)
// tbnnx = trade balance

//Missingg in the WID:
// tgxrx = exports goods
// tgmpx = imports goods
// tgnnx = trade balance goods
// tsxrx = exports services
// tsmpx = imports services
// tsnnx = trade balance services
*/



*Import data
use "$root\raw-data\\merge-historical-aggregates.dta",clear


keep if inlist(widcode,"mtbxrx999i", "mtbmpx999i", "mtbnnx999i", "mtgxrx999i" ,"mtgmpx999i" ,"mtgnnx999i") | ///
		inlist(widcode, "mtsxrx999i", "mtsmpx999i", "mtsnnx999i", "xlcusx999i","inyixx999i","mnninc999i")
ren iso country
gen corecountry=.
foreach c of global corecountries {
	replace corecountry=1 if country=="`c'"
	}
keep if (corecountry==1 | country=="WO")
keep year country value widcode
format value %30.10f
reshape wide value ,i(year country) j(widcode) string 
ren value* *
ren *999i *


*Generate relevant variables
foreach var in mtbxrx mtbmpx mtbnnx   	mtgxrx mtgmpx mtgnnx  	mtsxrx mtsmpx mtsnnx mnninc{
	g `var'_mer=((inyixx*`var')/xlcusx)/1000
}

// *Goods & services
// g tb_mer=mtbnnx_mer
// g nni_mer=mnninc_mer
		

*Goods
g tb_mer=mtgnnx_mer
g nni_mer=mnninc_mer
		
		
//		
// use main_dataset.dta,clear
// keep if year>=1970
// drop if country=="WO"
//
// *Generate relevant variables
// foreach var in nni tb exp imp{
// 	g `var'_mer=(nipi*`var')/mer_usd
// }

preserve
*Aggregate at the national-year level
collapse (sum) tb_mer nni_mer, by(year )
g tb_mer_ratioWorld=tb_mer/nni_mer
drop tb_mer nni_mer
save tb_mer_ratioWorld.dta,replace
restore 

merge m:1 country using largest.dta
keep if _merge==3
drop _merge
loc s countryname
		replace `s' = subinstr(`s', " ", "_", .)

*Aggregate at the region-year level
collapse (sum) tb_mer nni_mer, by(year countryname)

*Format in Figure format
g tb_mer_ratio=tb_mer/nni_mer
drop tb_mer nni_mer
reshape wide tb_mer_ratio , i(year) j(countryname) string
merge 1:1 year using tb_mer_ratioWorld.dta
drop _merge 
cap erase tb_mer_ratioWorld.dta

ren tb_mer_ratio* *

foreach var of varlist _all {
	label var `var' ""
}
 keep if inrange(year,1970,2023)
tsset year
tsline Brazil China France Germany India Indonesia Japan Russian_Federation USA United_Kingdom World, title("Net trade balance as % national income (MER)" "by country 1970-2023" "in current USD") note("Positive value: Trade surplus, meaning exports exceed imports. The larger the absolute value " "of the percentage, the more significant the trade imbalance is relative to the size of the economy.") lpattern(dash dash dash dash shortdash shortdash shortdash shortdash  ) legend(size(small) row(2)) lcolor(green red  blue cyan magenta gold orange purple brown pink black) 

*Export 
export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataF7b_large", modify) cell(A4) keepcellfmt




**# Figure 7g
/*------------------------------------------------------------------------------
Figure 7g. Net Trade Balance (Services) as % National Income (MER) for the Largest Economies 1970-2023
------------------------------------------------------------------------------*/
/*
This next code considers raw data (14-oct-2024) shared by Gaston, It is necesarry to change the code when the WID is updated and the goods and services variables are included in the dataset

//Already in the WID:
// tbxrx = exports (goods + services)
// tbmpx = imports (goods + services)
// tbnnx = trade balance

//Missingg in the WID:
// tgxrx = exports goods
// tgmpx = imports goods
// tgnnx = trade balance goods
// tsxrx = exports services
// tsmpx = imports services
// tsnnx = trade balance services
*/



*Import data
use "$root\raw-data\\merge-historical-aggregates.dta",clear


keep if inlist(widcode,"mtbxrx999i", "mtbmpx999i", "mtbnnx999i", "mtgxrx999i" ,"mtgmpx999i" ,"mtgnnx999i") | ///
		inlist(widcode, "mtsxrx999i", "mtsmpx999i", "mtsnnx999i", "xlcusx999i","inyixx999i","mnninc999i")
ren iso country
gen corecountry=.
foreach c of global corecountries {
	replace corecountry=1 if country=="`c'"
	}
keep if (corecountry==1 | country=="WO")
keep year country value widcode
format value %30.10f
reshape wide value ,i(year country) j(widcode) string 
ren value* *
ren *999i *


*Generate relevant variables
foreach var in mtbxrx mtbmpx mtbnnx   	mtgxrx mtgmpx mtgnnx  	mtsxrx mtsmpx mtsnnx mnninc{
	g `var'_mer=((inyixx*`var')/xlcusx)/1000
}

// *Goods & services
// g tb_mer=mtbnnx_mer
// g nni_mer=mnninc_mer
		

*Services
g tb_mer=mtsnnx_mer
g nni_mer=mnninc_mer
		
		
//		
// use main_dataset.dta,clear
// keep if year>=1970
// drop if country=="WO"
//
// *Generate relevant variables
// foreach var in nni tb exp imp{
// 	g `var'_mer=(nipi*`var')/mer_usd
// }

preserve
*Aggregate at the national-year level
collapse (sum) tb_mer nni_mer, by(year )
g tb_mer_ratioWorld=tb_mer/nni_mer
drop tb_mer nni_mer
save tb_mer_ratioWorld.dta,replace
restore 

merge m:1 country using largest.dta
keep if _merge==3
drop _merge
loc s countryname
		replace `s' = subinstr(`s', " ", "_", .)

*Aggregate at the region-year level
collapse (sum) tb_mer nni_mer, by(year countryname)

*Format in Figure format
g tb_mer_ratio=tb_mer/nni_mer
drop tb_mer nni_mer
reshape wide tb_mer_ratio , i(year) j(countryname) string
merge 1:1 year using tb_mer_ratioWorld.dta
drop _merge 
cap erase tb_mer_ratioWorld.dta

ren tb_mer_ratio* *

foreach var of varlist _all {
	label var `var' ""
}
 keep if inrange(year,1970,2023)
tsset year
tsline Brazil China France Germany India Indonesia Japan Russian_Federation USA United_Kingdom World, title("Net trade balance as % national income (MER)" "by country 1970-2023" "in current USD") note("Positive value: Trade surplus, meaning exports exceed imports. The larger the absolute value " "of the percentage, the more significant the trade imbalance is relative to the size of the economy.") lpattern(dash dash dash dash shortdash shortdash shortdash shortdash  ) legend(size(small) row(2)) lcolor(green red  blue cyan magenta gold orange purple brown pink black) 

*Export 
export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataF7c_large", modify) cell(A4) keepcellfmt





**# Figure 7h
/*------------------------------------------------------------------------------
Figure 7h. Net Trade Balance as % World Income (MER) for the Largest Economies 1970-2023
------------------------------------------------------------------------------*/
*Import data
use main_dataset.dta,clear
keep if year>=1970
drop if country=="WO"

*Generate relevant variables
foreach var in nni tb exp imp{
	g `var'_mer=(nipi*`var')/mer_usd
}


preserve
*Aggregate at the national-year level
collapse (sum)  nni_mer tb_mer, by(year )
ren nni_mer nni_mer_world
ren tb_mer tb_mer_world
save nni_mer_World.dta,replace
restore 

merge m:1 country using largest.dta
keep if _merge==3
drop _merge
loc s countryname
		replace `s' = subinstr(`s', " ", "_", .)

*Aggregate at the region-year level
collapse (sum) tb_mer nni_mer, by(year countryname)

merge m:1 year using nni_mer_World.dta
keep if _merge==3
drop _merge
cap erase nni_mer_World.dta
g tb_mer_world_ratio=tb_mer/nni_mer_world
g tb_mer_world_ratio_world=tb_mer_world/nni_mer_world

drop tb_mer nni_mer nni_mer_world
*Format in Figure format
replace countryname="Russia" if countryname=="Russian_Federation"
reshape wide tb_mer_world_ratio , i(year) j(countryname) string


ren tb_mer_world_ratio* *
ren _world World

foreach var of varlist _all {
	label var `var' ""
}
 drop tb_mer_world
tsset year
tsline Brazil China France Germany India Indonesia Japan Russia USA United_Kingdom World , title("Net trade balance as % world national income (MER)" "by country 1970-2023" "in current USD") note("Positive value: Trade surplus, meaning exports exceed imports. The larger the absolute value " "of the percentage, the more significant the trade imbalance is relative to the world economic output.") lpattern(dash dash dash dash shortdash shortdash shortdash shortdash  ) legend(size(small) row(2)) lcolor(green red  blue cyan magenta gold orange purple brown pink ) 

*Export 
export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataF7b_large", modify) cell(A4) keepcellfmt













**# Figure 8a
/*------------------------------------------------------------------------------
Figure 8a. Net Trade Balance as % National Income (PPP) by World Region 1970-2023
------------------------------------------------------------------------------*/
*Import data
use main_dataset.dta,clear
keep if year>=1970
drop if country=="WO"

*Generate relevant variables
foreach var in nni tb exp imp{
	g `var'_ppp=(nipi*`var')/ppp_2023_usd
}

preserve
*Aggregate at the national-year level
collapse (sum) tb_ppp nni_ppp, by(year )
g tb_ppp_ratioWorld=tb_ppp/nni_ppp
drop tb_ppp nni_ppp
save tb_ppp_ratioWorld.dta,replace
restore 

*Aggregate at the region-year level
collapse (sum) tb_ppp nni_ppp, by(year region)

*Format in Figure format
g tb_ppp_ratio=tb_ppp/nni_ppp
drop tb_ppp nni_ppp
reshape wide tb_ppp_ratio , i(year) j(region) string
merge 1:1 year using tb_ppp_ratioWorld.dta
drop _merge 
cap erase tb_ppp_ratioWorld.dta

tsset year
tsline tb_ppp_ratioEASA tb_ppp_ratioEURO tb_ppp_ratioLATA tb_ppp_ratioMENA tb_ppp_ratioNAOC tb_ppp_ratioRUCA tb_ppp_ratioSSAF tb_ppp_ratioSSEA tb_ppp_ratioWorld

*Export 
export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataF8", modify) cell(A4) keepcellfmt




**# Figure 8b
/*------------------------------------------------------------------------------
Figure 8b. Net Trade Balance as % World Income (PPP) by World Region 1970-2023
------------------------------------------------------------------------------*/
*Import data
use main_dataset.dta,clear
keep if year>=1970
 drop if country=="WO"

*Generate relevant variables
foreach var in nni tb exp imp{
	g `var'_ppp=(nipi*`var')/ppp_2023_usd
}


preserve
*Aggregate at the national-year level
drop if country=="WO"
collapse (sum)  nni_ppp tb_ppp, by(year )
ren nni_ppp nni_ppp_world
ren tb_ppp tb_ppp_world
save nni_ppp_World.dta,replace
restore 

*Aggregate at the region-year level
collapse (sum) tb_ppp nni_ppp, by(year region)

merge m:1 year using nni_ppp_World.dta
keep if _merge==3
drop _merge
cap erase nni_ppp_World.dta
g tb_ppp_world_ratio=tb_ppp/nni_ppp_world
g tb_ppp_world_ratio_world=tb_ppp_world/nni_ppp_world

drop tb_ppp nni_ppp nni_ppp_world tb_ppp_world
*Format in Figure format
reshape wide tb_ppp_world_ratio tb_ppp_world_ratio_world, i(year) j(region) string


ren tb_ppp_world_ratio* *
keep year EASA EURO LATA MENA NAOC RUCA SSAF SSEA _worldEASA
ren _worldEASA World

tsset year
tsline EASA EURO LATA MENA NAOC RUCA SSAF SSEA World
order year EASA EURO LATA MENA NAOC RUCA SSAF SSEA World

*Export 
export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataF8b", modify) cell(A4) keepcellfmt











	









**# Figure 8c
/*------------------------------------------------------------------------------
Figure 8c. Net Trade Balance as % National Income (PPP) for the Largest Economies 1970-2023
------------------------------------------------------------------------------*/
*Import data
use main_dataset.dta,clear
keep if year>=1970
drop if country=="WO"

*Generate relevant variables
foreach var in nni tb exp imp{
	g `var'_ppp=(nipi*`var')/ppp_2023_usd
}

preserve
*Aggregate at the national-year level
collapse (sum) tb_ppp nni_ppp, by(year )
g tb_ppp_ratioWorld=tb_ppp/nni_ppp
drop tb_ppp nni_ppp
save tb_ppp_ratioWorld.dta,replace
restore 

merge m:1 country using largest.dta
keep if _merge==3
drop _merge
loc s countryname
		replace `s' = subinstr(`s', " ", "_", .)

*Aggregate at the region-year level
collapse (sum) tb_ppp nni_ppp, by(year countryname)

*Format in Figure format
g tb_ppp_ratio=tb_ppp/nni_ppp
drop tb_ppp nni_ppp
reshape wide tb_ppp_ratio , i(year) j(countryname) string
merge 1:1 year using tb_ppp_ratioWorld.dta
drop _merge 
cap erase tb_ppp_ratioWorld.dta

ren tb_ppp_ratio* *

foreach var of varlist _all {
	label var `var' ""
}
 
tsset year
tsline Brazil China France Germany India Indonesia Japan Russian_Federation USA United_Kingdom World, title("Net trade balance as % national income (PPP)" "by country 1970-2023" "in current USD") note("Positive value: Trade surplus, meaning exports exceed imports. The larger the absolute value " "of the percentage, the more significant the trade imbalance is relative to the size of the economy.") lpattern(dash dash dash dash shortdash shortdash shortdash shortdash  ) legend(size(small) row(2)) lcolor(green red  blue cyan magenta gold orange purple brown pink black) 

*Export 
export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataF8_large", modify) cell(A4) keepcellfmt




**# Figure 8d
/*------------------------------------------------------------------------------
Figure 8d. Net Trade Balance as % World Income (PPP) for the Largest Economies 1970-2023
------------------------------------------------------------------------------*/
*Import data
use main_dataset.dta,clear
keep if year>=1970
drop if country=="WO"

*Generate relevant variables
foreach var in nni tb exp imp{
	g `var'_ppp=(nipi*`var')/ppp_2023_usd
}


preserve
*Aggregate at the national-year level
collapse (sum)  nni_ppp tb_ppp, by(year )
ren nni_ppp nni_ppp_world
ren tb_ppp tb_ppp_world
save nni_ppp_World.dta,replace
restore 

merge m:1 country using largest.dta
keep if _merge==3
drop _merge
loc s countryname
		replace `s' = subinstr(`s', " ", "_", .)

*Aggregate at the region-year level
collapse (sum) tb_ppp nni_ppp, by(year countryname)

merge m:1 year using nni_ppp_World.dta
keep if _merge==3
drop _merge
cap erase nni_ppp_World.dta
g tb_ppp_world_ratio=tb_ppp/nni_ppp_world
g tb_ppp_world_ratio_world=tb_ppp_world/nni_ppp_world

drop tb_ppp nni_ppp nni_ppp_world tb_ppp_world
*Format in Figure format
replace countryname="Russia" if countryname=="Russian_Federation"
reshape wide tb_ppp_world_ratio , i(year) j(countryname) string


ren tb_ppp_world_ratio* *
ren _world World 


foreach var of varlist _all {
	label var `var' ""
}
 
tsset year
tsline Brazil China France Germany India Indonesia Japan Russia USA United_Kingdom World, title("Net trade balance as % world national income (PPP)" "by country 1970-2023" "in current USD") note("Positive value: Trade surplus, meaning exports exceed imports. The larger the absolute value " "of the percentage, the more significant the trade imbalance is relative to the world economic output.") lpattern(dash dash dash dash shortdash shortdash shortdash shortdash  ) legend(size(small) row(2)) lcolor(green red  blue cyan magenta gold orange purple brown pink ) 

*Export 
export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataF8b_large", modify) cell(A4) keepcellfmt

