
**# Table 14
/*------------------------------------------------------------------------------
Table 14. Per Capita National Income and Public Spending (PPP 2023 €)
------------------------------------------------------------------------------*/

*Import data
use main_dataset.dta,clear
keep if year==2023
drop if country=="WO"

*Generate relevant variables
foreach var in gni pr tr ntr ps pse psh ehs sp ops psur ip ssur{
	g `var'_ppp=`var'/ppp_2023_eur
	g `var'_ppp_pc=`var'_ppp/poptot
}


 *Sort from lowest to highest per capita national income (PPP)
 sort gni_ppp_pc
 
 *Classify according to per capita net national income
 egen seq=seq()
 g percentile=""
 replace percentile="0%-10%" if inrange(seq,1,22)
 replace percentile="10%-20%" if inrange(seq,23,44)
 replace percentile="20%-30%" if inrange(seq,45,66)
 replace percentile="30%-40%" if inrange(seq,67,87)
 replace percentile="40%-50%" if inrange(seq,88,108) 
 replace percentile="50%-60%" if inrange(seq,109,129)
 replace percentile="60%-70%" if inrange(seq,130,150)
 replace percentile="70%-80%" if inrange(seq,151,172)
 replace percentile="80%-90%" if inrange(seq,173,194)
 replace percentile="90%-100%" if inrange(seq,195,216) 
 
 
 *Compute for World 
preserve
	collapse (sum) poptot  gni_ppp pr_ppp tr_ppp ntr_ppp ps_ppp ehs_ppp sp_ppp ops_ppp psur_ppp ip_ppp ssur_ppp
	sum poptot
	loc poptot=r(mean)
	foreach var in gni {
		sum `var'_ppp
		loc gni_ppp=r(mean)
		loc `var'_ppp_pc= `gni_ppp'/`poptot'
	}
	foreach var in pr tr ntr ps ehs sp ops psur ip ssur{
		sum `var'_ppp
		loc `var'_ppp_ratio=r(mean)/`gni_ppp'
	}
restore

 *Compute per percentile
 collapse (sum) poptot gni_ppp pr_ppp tr_ppp ntr_ppp ps_ppp ehs_ppp sp_ppp ops_ppp psur_ppp  ip_ppp ssur_ppp,by(percentile)
 
foreach var in gni {
	g `var'_ppp_pc=`var'_ppp/poptot
}

foreach var in pr tr ntr ps ehs sp ops psur ip ssur{
	g `var'_ppp_ratio=`var'_ppp/gni_ppp	
}
 
*Include World 
set obs `=_N+1'
	replace percentile="World" if percentile==""
	foreach var in gni {
		replace `var'_ppp_pc=``var'_ppp_pc' if percentile=="World" & `var'_ppp_pc==.
	}
	foreach var in pr tr ntr ps ehs sp ops psur ip ssur{
		replace `var'_ppp_ratio=``var'_ppp_ratio' if percentile=="World" & `var'_ppp_ratio==.
	}
	
*Format for exporting	
order percentile gni_ppp_pc 
drop poptot gni_ppp pr_ppp tr_ppp ntr_ppp ps_ppp ehs_ppp sp_ppp ops_ppp psur_ppp ip_ppp ssur_ppp


*Export to excel
export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataT14", modify) cell(A4) keepcellfmt




**# Figure 9a
/*------------------------------------------------------------------------------
Public Revenue as % Gross National Income (PPP) by World Region 1980-2023
------------------------------------------------------------------------------*/
*Import data
use main_dataset.dta,clear
keep if year>=1980
drop if country=="WO"

*Generate relevant variables
foreach var in gni pr tr ntr ps ehs sp ops psur ip ssur{
	g `var'_ppp=`var'/ppp_2023_eur
}

preserve
*Aggregate at the national-year level
collapse (sum) pr_ppp gni_ppp, by(year )
g pr_ppp_ratioWorld=pr_ppp/gni_ppp
drop pr_ppp gni_ppp
save pr_ppp_ratioWorld.dta,replace
restore 

*Aggregate at the region-year level
collapse (sum) pr_ppp gni_ppp, by(year region)

*Format in Figure format
g pr_ppp_ratio=pr_ppp/gni_ppp
drop pr_ppp gni_ppp
reshape wide pr_ppp_ratio , i(year) j(region) string
merge 1:1 year using pr_ppp_ratioWorld.dta
drop _merge 
cap erase pr_ppp_ratioWorld.dta

tsset year
tsline pr_ppp_ratioEASA pr_ppp_ratioEURO pr_ppp_ratioLATA pr_ppp_ratioMENA pr_ppp_ratioNAOC pr_ppp_ratioRUCA pr_ppp_ratioSSAF pr_ppp_ratioSSEA pr_ppp_ratioWorld

*Export 
export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataF9", modify) cell(A4) keepcellfmt



**# Figure 10a
/*------------------------------------------------------------------------------
Figure 10a. Tax Revenue as % Gross National Income (PPP) by World Region 1980-2023
------------------------------------------------------------------------------*/
*Import data
use main_dataset.dta,clear
keep if year>=1980
drop if country=="WO"

*Generate relevant variables
foreach var in gni pr tr ntr ps ehs sp ops psur ip ssur{
	g `var'_ppp=`var'/ppp_2023_eur
}

preserve
*Aggregate at the national-year level
collapse (sum) tr_ppp gni_ppp, by(year )
g tr_ppp_ratioWorld=tr_ppp/gni_ppp
drop tr_ppp gni_ppp
save tr_ppp_ratioWorld.dta,replace
restore 

*Aggregate at the region-year level
collapse (sum) tr_ppp gni_ppp, by(year region)

*Format in Figure format
g tr_ppp_ratio=tr_ppp/gni_ppp
drop tr_ppp gni_ppp
reshape wide tr_ppp_ratio , i(year) j(region) string
merge 1:1 year using tr_ppp_ratioWorld.dta
drop _merge 
cap erase tr_ppp_ratioWorld.dta

tsset year
tsline tr_ppp_ratioEASA tr_ppp_ratioEURO tr_ppp_ratioLATA tr_ppp_ratioMENA tr_ppp_ratioNAOC tr_ppp_ratioRUCA tr_ppp_ratioSSAF tr_ppp_ratioSSEA tr_ppp_ratioWorld

*Export 
export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataF10", modify) cell(A4) keepcellfmt


**# Figure 11a
/*------------------------------------------------------------------------------
Figure 11a. Non-tax Revenue as % Gross National Income (PPP) by World Region 1980-2023
------------------------------------------------------------------------------*/

*Import data
use main_dataset.dta,clear
keep if year>=1980
drop if country=="WO"

*Generate relevant variables
foreach var in gni pr tr ntr ps ehs sp ops psur ip ssur{
	g `var'_ppp=`var'/ppp_2023_eur
}

preserve
*Aggregate at the national-year level
collapse (sum) ntr_ppp gni_ppp, by(year )
g ntr_ppp_ratioWorld=ntr_ppp/gni_ppp
drop ntr_ppp gni_ppp
save ntr_ppp_ratioWorld.dta,replace
restore 

*Aggregate at the region-year level
collapse (sum) ntr_ppp gni_ppp, by(year region)

*Format in Figure format
g ntr_ppp_ratio=ntr_ppp/gni_ppp
drop ntr_ppp gni_ppp
reshape wide ntr_ppp_ratio , i(year) j(region) string
merge 1:1 year using ntr_ppp_ratioWorld.dta
drop _merge 
cap erase ntr_ppp_ratioWorld.dta

tsset year
tsline ntr_ppp_ratioEASA ntr_ppp_ratioEURO ntr_ppp_ratioLATA ntr_ppp_ratioMENA ntr_ppp_ratioNAOC ntr_ppp_ratioRUCA ntr_ppp_ratioSSAF ntr_ppp_ratioSSEA ntr_ppp_ratioWorld

*Export 
export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataF11", modify) cell(A4) keepcellfmt




**# Figure 12a
/*------------------------------------------------------------------------------
Figure 12a. Public Spending as % Gross National Income (PPP) by World Region 1980-2023
------------------------------------------------------------------------------*/

*Import data
use main_dataset.dta,clear
keep if year>=1980
drop if country=="WO"

*Generate relevant variables
foreach var in gni pr tr ntr ps ehs sp ops psur ip ssur{
	g `var'_ppp=`var'/ppp_2023_eur
}

preserve
*Aggregate at the national-year level
collapse (sum) ps_ppp gni_ppp, by(year )
g ps_ppp_ratioWorld=ps_ppp/gni_ppp
drop ps_ppp gni_ppp
save ps_ppp_ratioWorld.dta,replace
restore 

*Aggregate at the region-year level
collapse (sum) ps_ppp gni_ppp, by(year region)

*Format in Figure format
g ps_ppp_ratio=ps_ppp/gni_ppp
drop ps_ppp gni_ppp
reshape wide ps_ppp_ratio , i(year) j(region) string
merge 1:1 year using ps_ppp_ratioWorld.dta
drop _merge 
cap erase ps_ppp_ratioWorld.dta

tsset year
tsline ps_ppp_ratioEASA ps_ppp_ratioEURO ps_ppp_ratioLATA ps_ppp_ratioMENA ps_ppp_ratioNAOC ps_ppp_ratioRUCA ps_ppp_ratioSSAF ps_ppp_ratioSSEA ps_ppp_ratioWorld

*Export 
export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataF12", modify) cell(A4) keepcellfmt



**# Figure 13a
/*------------------------------------------------------------------------------
Figure 13a. Public Spending in Education and Health as % Gross National Income (PPP) by World Region 1980-2023
------------------------------------------------------------------------------*/

*Import data
use main_dataset.dta,clear
keep if year>=1980
drop if country=="WO"

*Generate relevant variables
foreach var in gni pr tr ntr ps ehs sp ops psur ip ssur{
	g `var'_ppp=`var'/ppp_2023_eur
}

preserve
*Aggregate at the national-year level
collapse (sum) ehs_ppp gni_ppp, by(year )
g ehs_ppp_ratioWorld=ehs_ppp/gni_ppp
drop ehs_ppp gni_ppp
save ehs_ppp_ratioWorld.dta,replace
restore 

*Aggregate at the region-year level
collapse (sum) ehs_ppp gni_ppp, by(year region)

*Format in Figure format
g ehs_ppp_ratio=ehs_ppp/gni_ppp
drop ehs_ppp gni_ppp
reshape wide ehs_ppp_ratio , i(year) j(region) string
merge 1:1 year using ehs_ppp_ratioWorld.dta
drop _merge 
cap erase ehs_ppp_ratioWorld.dta

tsset year
tsline ehs_ppp_ratioEASA ehs_ppp_ratioEURO ehs_ppp_ratioLATA ehs_ppp_ratioMENA ehs_ppp_ratioNAOC ehs_ppp_ratioRUCA ehs_ppp_ratioSSAF ehs_ppp_ratioSSEA ehs_ppp_ratioWorld

*Export 
export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataF13", modify) cell(A4) keepcellfmt




**# Figure 13c
/*------------------------------------------------------------------------------
Figure 13c. Public Spending in Health as % Gross National Income (PPP) by World Region 1980-2023
------------------------------------------------------------------------------*/

*Import data
use main_dataset.dta,clear
keep if year>=1980
drop if country=="WO"

*Generate relevant variables
foreach var in gni pr tr ntr ps psh ehs sp ops psur ip ssur {
	g `var'_ppp=`var'/ppp_2023_eur
}

preserve
*Aggregate at the national-year level
collapse (sum) psh_ppp gni_ppp, by(year )
g psh_ppp_ratioWorld=psh_ppp/gni_ppp
drop psh_ppp gni_ppp
save psh_ppp_ratioWorld.dta,replace
restore 

*Aggregate at the region-year level
collapse (sum) psh_ppp gni_ppp, by(year region)

*Format in Figure format
g psh_ppp_ratio=psh_ppp/gni_ppp
drop psh_ppp gni_ppp
reshape wide psh_ppp_ratio , i(year) j(region) string
merge 1:1 year using psh_ppp_ratioWorld.dta
drop _merge 
cap erase psh_ppp_ratioWorld.dta

tsset year
tsline psh_ppp_ratioEASA psh_ppp_ratioEURO psh_ppp_ratioLATA psh_ppp_ratioMENA psh_ppp_ratioNAOC psh_ppp_ratioRUCA psh_ppp_ratioSSAF psh_ppp_ratioSSEA psh_ppp_ratioWorld

*Export 
export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataF13_b", modify) cell(A4) keepcellfmt



**# Figure 13e
/*------------------------------------------------------------------------------
Figure 13e. Public Spending in Education as % Gross National Income (PPP) by World Region 1980-2023
------------------------------------------------------------------------------*/

*Import data
use main_dataset.dta,clear
keep if year>=1980
drop if country=="WO"

*Generate relevant variables
foreach var in gni pr tr ntr ps pse ehs sp ops psur ip ssur {
	g `var'_ppp=`var'/ppp_2023_eur
}

preserve
*Aggregate at the national-year level
collapse (sum) pse_ppp gni_ppp, by(year )
g pse_ppp_ratioWorld=pse_ppp/gni_ppp
drop pse_ppp gni_ppp
save pse_ppp_ratioWorld.dta,replace
restore 

*Aggregate at the region-year level
collapse (sum) pse_ppp gni_ppp, by(year region)

*Format in Figure format
g pse_ppp_ratio=pse_ppp/gni_ppp
drop pse_ppp gni_ppp
reshape wide pse_ppp_ratio , i(year) j(region) string
merge 1:1 year using pse_ppp_ratioWorld.dta
drop _merge 
cap erase pse_ppp_ratioWorld.dta

tsset year
tsline pse_ppp_ratioEASA pse_ppp_ratioEURO pse_ppp_ratioLATA pse_ppp_ratioMENA pse_ppp_ratioNAOC pse_ppp_ratioRUCA pse_ppp_ratioSSAF pse_ppp_ratioSSEA pse_ppp_ratioWorld

*Export 
export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataF13_c", modify) cell(A4) keepcellfmt


**# Figure 14a
/*------------------------------------------------------------------------------
Figure 14a. Public Spending in Social Protection as % Gross National Income (PPP) by World Region 1980-2023
------------------------------------------------------------------------------*/
*Import data
use main_dataset.dta,clear
keep if year>=1980
drop if country=="WO"

*Generate relevant variables
foreach var in gni pr tr ntr ps ehs sp ops psur ip ssur{
	g `var'_ppp=`var'/ppp_2023_eur
}

preserve
*Aggregate at the national-year level
collapse (sum) sp_ppp gni_ppp, by(year )
g sp_ppp_ratioWorld=sp_ppp/gni_ppp
drop sp_ppp gni_ppp
save sp_ppp_ratioWorld.dta,replace
restore 

*Aggregate at the region-year level
collapse (sum) sp_ppp gni_ppp, by(year region)

*Format in Figure format
g sp_ppp_ratio=sp_ppp/gni_ppp
drop sp_ppp gni_ppp
reshape wide sp_ppp_ratio , i(year) j(region) string
merge 1:1 year using sp_ppp_ratioWorld.dta
drop _merge 
cap erase sp_ppp_ratioWorld.dta

tsset year
tsline sp_ppp_ratioEASA sp_ppp_ratioEURO sp_ppp_ratioLATA sp_ppp_ratioMENA sp_ppp_ratioNAOC sp_ppp_ratioRUCA sp_ppp_ratioSSAF sp_ppp_ratioSSEA sp_ppp_ratioWorld

*Export 
export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataF14", modify) cell(A4) keepcellfmt



**# Figure 15a
/*------------------------------------------------------------------------------
Figure 15a. Other Public Spending as % Gross National Income (PPP) by World Region 1980-2023
------------------------------------------------------------------------------*/
*Import data
use main_dataset.dta,clear
keep if year>=1980
drop if country=="WO"

*Generate relevant variables
foreach var in gni pr tr ntr ps ehs sp ops psur ip ssur{
	g `var'_ppp=`var'/ppp_2023_eur
}

preserve
*Aggregate at the national-year level
collapse (sum) ops_ppp gni_ppp, by(year )
g ops_ppp_ratioWorld=ops_ppp/gni_ppp
drop ops_ppp gni_ppp
save ops_ppp_ratioWorld.dta,replace
restore 

*Aggregate at the region-year level
collapse (sum) ops_ppp gni_ppp, by(year region)

*Format in Figure format
g ops_ppp_ratio=ops_ppp/gni_ppp
drop ops_ppp gni_ppp
reshape wide ops_ppp_ratio , i(year) j(region) string
merge 1:1 year using ops_ppp_ratioWorld.dta
drop _merge 
cap erase ops_ppp_ratioWorld.dta

tsset year
tsline ops_ppp_ratioEASA ops_ppp_ratioEURO ops_ppp_ratioLATA ops_ppp_ratioMENA ops_ppp_ratioNAOC ops_ppp_ratioRUCA ops_ppp_ratioSSAF ops_ppp_ratioSSEA ops_ppp_ratioWorld

*Export 
export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataF15", modify) cell(A4) keepcellfmt




**# Figure 16a
/*------------------------------------------------------------------------------
Figure 16a. Primary Surplus as % Gross National Income (PPP) by World Region 1980-2023
------------------------------------------------------------------------------*/
*Import data
use main_dataset.dta,clear
keep if year>=1980
drop if country=="WO"

*Generate relevant variables
foreach var in gni pr tr ntr ps ehs sp ops psur ip ssur{
	g `var'_ppp=`var'/ppp_2023_eur
}

preserve
*Aggregate at the national-year level
collapse (sum) psur_ppp gni_ppp, by(year )
g psur_ppp_ratioWorld=psur_ppp/gni_ppp
drop psur_ppp gni_ppp
save psur_ppp_ratioWorld.dta,replace
restore 

*Aggregate at the region-year level
collapse (sum) psur_ppp gni_ppp, by(year region)

*Format in Figure format
g psur_ppp_ratio=psur_ppp/gni_ppp
drop psur_ppp gni_ppp
reshape wide psur_ppp_ratio , i(year) j(region) string
merge 1:1 year using psur_ppp_ratioWorld.dta
drop _merge 
cap erase psur_ppp_ratioWorld.dta

tsset year
tsline psur_ppp_ratioEASA psur_ppp_ratioEURO psur_ppp_ratioLATA psur_ppp_ratioMENA psur_ppp_ratioNAOC psur_ppp_ratioRUCA psur_ppp_ratioSSAF psur_ppp_ratioSSEA psur_ppp_ratioWorld

*Export 
export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataF16", modify) cell(A4) keepcellfmt




**# Figure 17a
/*------------------------------------------------------------------------------
Figure 17a. Interest Payments as % Gross National Income (PPP) by World Region 1980-2023
------------------------------------------------------------------------------*/
*Import data
use main_dataset.dta,clear
keep if year>=1980
drop if country=="WO"

*Generate relevant variables
foreach var in gni pr tr ntr ps ehs sp ops psur ip ssur{
	g `var'_ppp=`var'/ppp_2023_eur
}

preserve
*Aggregate at the national-year level
collapse (sum) ip_ppp gni_ppp, by(year )
g ip_ppp_ratioWorld=ip_ppp/gni_ppp
drop ip_ppp gni_ppp
save ip_ppp_ratioWorld.dta,replace
restore 

*Aggregate at the region-year level
collapse (sum) ip_ppp gni_ppp, by(year region)

*Format in Figure format
g ip_ppp_ratio=ip_ppp/gni_ppp
drop ip_ppp gni_ppp
reshape wide ip_ppp_ratio , i(year) j(region) string
merge 1:1 year using ip_ppp_ratioWorld.dta
drop _merge 
cap erase ip_ppp_ratioWorld.dta

tsset year
tsline ip_ppp_ratioEASA ip_ppp_ratioEURO ip_ppp_ratioLATA ip_ppp_ratioMENA ip_ppp_ratioNAOC ip_ppp_ratioRUCA ip_ppp_ratioSSAF ip_ppp_ratioSSEA ip_ppp_ratioWorld

*Export 
export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataF17", modify) cell(A4) keepcellfmt











**# Figure 9b
/*------------------------------------------------------------------------------
Figure 9b. Public Revenue as % Gross National Income for the Largest Economies 1980-2023
------------------------------------------------------------------------------*/
*Import data
use main_dataset.dta,clear
keep if year>=1980
drop if country=="WO"

*Generate relevant variables
foreach var in gni pr tr ntr ps ehs sp ops psur ip ssur{
	g `var'_ppp=`var'/ppp_2023_eur
}

preserve
*Aggregate at the national-year level
collapse (sum) pr_ppp gni_ppp, by(year )
g pr_ppp_ratioWorld=pr_ppp/gni_ppp
drop pr_ppp gni_ppp
save pr_ppp_ratioWorld.dta,replace
restore 

merge m:1 country using largest.dta
keep if _merge==3
drop _merge
loc s countryname
		replace `s' = subinstr(`s', " ", "_", .)

*Aggregate at the region-year level
collapse (sum) pr_ppp gni_ppp, by(year countryname)

*Format in Figure format
g pr_ppp_ratio=pr_ppp/gni_ppp
drop pr_ppp gni_ppp
reshape wide pr_ppp_ratio , i(year) j(countryname) string
merge 1:1 year using pr_ppp_ratioWorld.dta
drop _merge 
cap erase pr_ppp_ratioWorld.dta

ren pr_ppp_ratio* *

foreach var of varlist _all {
	label var `var' ""
}
 
tsset year
tsline Brazil China France Germany India Indonesia Japan Russia USA United_Kingdom , title("Public revenue as % national income (PPP)" "by country 1980-2023") note("Interpretation:  Income collected by governments through taxes, fees, fines, and other sources as relative to" "the country's economic output.") lpattern(dash dash dash dash shortdash shortdash shortdash shortdash  ) legend(size(small) row(2)) lcolor(green red  blue cyan magenta gold orange purple brown pink ) 

*Export 
export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataF9_large", modify) cell(A4) keepcellfmt



**# Figure 10b
/*------------------------------------------------------------------------------
Figure 10b. Tax Revenue as % Gross National Income for the Largest Economies 1980-2023
------------------------------------------------------------------------------*/
*Import data
use main_dataset.dta,clear
keep if year>=1980
drop if country=="WO"

*Generate relevant variables
foreach var in gni pr tr ntr ps ehs sp ops psur ip ssur{
	g `var'_ppp=`var'/ppp_2023_eur
}

preserve
*Aggregate at the national-year level
collapse (sum) tr_ppp gni_ppp, by(year )
g tr_ppp_ratioWorld=tr_ppp/gni_ppp
drop tr_ppp gni_ppp
save tr_ppp_ratioWorld.dta,replace
restore 

merge m:1 country using largest.dta
keep if _merge==3
drop _merge
loc s countryname
		replace `s' = subinstr(`s', " ", "_", .)

*Aggregate at the region-year level
collapse (sum) tr_ppp gni_ppp, by(year countryname)

*Format in Figure format
g tr_ppp_ratio=tr_ppp/gni_ppp
drop tr_ppp gni_ppp
reshape wide tr_ppp_ratio , i(year) j(countryname) string
merge 1:1 year using tr_ppp_ratioWorld.dta
drop _merge 
cap erase tr_ppp_ratioWorld.dta

ren tr_ppp_ratio* *

foreach var of varlist _all {
	label var `var' ""
}
 
tsset year
tsline Brazil China France Germany India Indonesia Japan Russia USA United_Kingdom , title("Tax revenue as % national income (PPP)" "by country 1980-2023") note("Interpretation:  Government's fiscal capacity and tax burden as relative to the country's economic" " output." "Countries with tax revenue below 15% of GDP are often considered to have insufficient fiscal capacity.") lpattern(dash dash dash dash shortdash shortdash shortdash shortdash  ) legend(size(small) row(2)) lcolor(green red  blue cyan magenta gold orange purple brown pink ) yla(0(.15).6)

*Export 
export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataF10_large", modify) cell(A4) keepcellfmt


**# Figure 11b
/*------------------------------------------------------------------------------
Figure 11b. Non-tax Revenue as % Gross National Income for the Largest Economies 1980-2023
------------------------------------------------------------------------------*/

*Import data
use main_dataset.dta,clear
keep if year>=1980
drop if country=="WO"

*Generate relevant variables
foreach var in gni pr tr ntr ps ehs sp ops psur ip ssur{
	g `var'_ppp=`var'/ppp_2023_eur
}

preserve
*Aggregate at the national-year level
collapse (sum) ntr_ppp gni_ppp, by(year )
g ntr_ppp_ratioWorld=ntr_ppp/gni_ppp
drop ntr_ppp gni_ppp
save ntr_ppp_ratioWorld.dta,replace
restore 

merge m:1 country using largest.dta
keep if _merge==3
drop _merge
loc s countryname
		replace `s' = subinstr(`s', " ", "_", .)

*Aggregate at the region-year level
collapse (sum) ntr_ppp gni_ppp, by(year countryname)

*Format in Figure format
g ntr_ppp_ratio=ntr_ppp/gni_ppp
drop ntr_ppp gni_ppp
reshape wide ntr_ppp_ratio , i(year) j(countryname) string
merge 1:1 year using ntr_ppp_ratioWorld.dta
drop _merge 
cap erase ntr_ppp_ratioWorld.dta

ren ntr_ppp_ratio* *

foreach var of varlist _all {
	label var `var' ""
}
 
tsset year
tsline Brazil China France Germany India Indonesia Japan Russia USA United_Kingdom , title("Non-tax revenue as % national income (PPP)" "by country 1980-2023") note("Interpretation:  Revenues from natural resources, fees, fines, and other government income that does not" "come from taxation as relative to the country's economic output." "Countries that rely heavily on non-tax revenue, particularly from natural resources, may experience" "a political resource curse.") lpattern(dash dash dash dash shortdash shortdash shortdash shortdash  ) legend(size(small) row(2)) lcolor(green red  blue cyan magenta gold orange purple brown pink ) yla(0(.05).25)

*Export 
export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataF11_large", modify) cell(A4) keepcellfmt




**# Figure 12b
/*------------------------------------------------------------------------------
Figure 12b. Public Spending as % Gross National Income for the Largest Economies 1980-2023
------------------------------------------------------------------------------*/

*Import data
use main_dataset.dta,clear
keep if year>=1980
drop if country=="WO"

*Generate relevant variables
foreach var in gni pr tr ntr ps ehs sp ops psur ip ssur{
	g `var'_ppp=`var'/ppp_2023_eur
}

preserve
*Aggregate at the national-year level
collapse (sum) ps_ppp gni_ppp, by(year )
g ps_ppp_ratioWorld=ps_ppp/gni_ppp
drop ps_ppp gni_ppp
save ps_ppp_ratioWorld.dta,replace
restore 

merge m:1 country using largest.dta
keep if _merge==3
drop _merge
loc s countryname
		replace `s' = subinstr(`s', " ", "_", .)

*Aggregate at the region-year level
collapse (sum) ps_ppp gni_ppp, by(year countryname)

*Format in Figure format
g ps_ppp_ratio=ps_ppp/gni_ppp
drop ps_ppp gni_ppp
reshape wide ps_ppp_ratio , i(year) j(countryname) string
merge 1:1 year using ps_ppp_ratioWorld.dta
drop _merge 
cap erase ps_ppp_ratioWorld.dta

ren ps_ppp_ratio* *

foreach var of varlist _all {
	label var `var' ""
}
 
tsset year
tsline Brazil China France Germany India Indonesia Japan Russia USA United_Kingdom , title("Public spending as % national income (PPP)" "by country 1980-2023") note("Interpretation:  Economic influence of the government as relative to the country's economic output." "Lower percentages imply a more limited government role and possibly greater reliance on the private sector.") lpattern(dash dash dash dash shortdash shortdash shortdash shortdash  ) legend(size(small) row(2)) lcolor(green red  blue cyan magenta gold orange purple brown pink ) 

*Export 
export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataF12_large", modify) cell(A4) keepcellfmt



**# Figure 13b
/*------------------------------------------------------------------------------
Figure 13b. Public Spending in education and health as % Gross National Income for the Largest Economies 1980-2023
------------------------------------------------------------------------------*/

*Import data
use main_dataset.dta,clear
keep if year>=1980
drop if country=="WO"

*Generate relevant variables
foreach var in gni pr tr ntr ps ehs sp ops psur ip ssur{
	g `var'_ppp=`var'/ppp_2023_eur
}

preserve
*Aggregate at the national-year level
collapse (sum) ehs_ppp gni_ppp, by(year )
g ehs_ppp_ratioWorld=ehs_ppp/gni_ppp
drop ehs_ppp gni_ppp
save ehs_ppp_ratioWorld.dta,replace
restore 

merge m:1 country using largest.dta
keep if _merge==3
drop _merge
loc s countryname
		replace `s' = subinstr(`s', " ", "_", .)

*Aggregate at the region-year level
collapse (sum) ehs_ppp gni_ppp, by(year countryname)

*Format in Figure format
g ehs_ppp_ratio=ehs_ppp/gni_ppp
drop ehs_ppp gni_ppp
reshape wide ehs_ppp_ratio , i(year) j(countryname) string
merge 1:1 year using ehs_ppp_ratioWorld.dta
drop _merge 
cap erase ehs_ppp_ratioWorld.dta

ren ehs_ppp_ratio* *

foreach var of varlist _all {
	label var `var' ""
}
 
tsset year
tsline Brazil China France Germany India Indonesia Japan Russia USA United_Kingdom , title("Public spending in education and health as " "% national income (PPP) by country 1980-2023") note("Interpretation:  Public spending on education typically ranges from 2-6% of GDP, while health spending ranges" "from 1-8% of GDP." "Low-income countries typically spend 3-4% on education and 1-2% on health, middle-income countries 4-5%" "and 3-4%, and high-income countries 5-6% and 6-8% of GDP, respectively.") lpattern(dash dash dash dash shortdash shortdash shortdash shortdash  ) legend(size(small) row(2)) lcolor(green red  blue cyan magenta gold orange purple brown pink ) 

*Export 
export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataF13_large", modify) cell(A4) keepcellfmt


**# Figure 13d
/*------------------------------------------------------------------------------
Figure 13d. Public Spending in Health as % Gross National Income for the Largest Economies 1980-2023
------------------------------------------------------------------------------*/

*Import data
use main_dataset.dta,clear
keep if year>=1980
drop if country=="WO"

*Generate relevant variables
foreach var in gni pr tr ntr ps ehs psh pse sp ops psur ip ssur{
	g `var'_ppp=`var'/ppp_2023_eur
}

preserve
*Aggregate at the national-year level
collapse (sum) psh_ppp gni_ppp, by(year )
g psh_ppp_ratioWorld=psh_ppp/gni_ppp
drop psh_ppp gni_ppp
save psh_ppp_ratioWorld.dta,replace
restore 

merge m:1 country using largest.dta
keep if _merge==3
drop _merge
loc s countryname
		replace `s' = subinstr(`s', " ", "_", .)

*Aggregate at the region-year level
collapse (sum) psh_ppp gni_ppp, by(year countryname)

*Format in Figure format
g psh_ppp_ratio=psh_ppp/gni_ppp
drop psh_ppp gni_ppp
reshape wide psh_ppp_ratio , i(year) j(countryname) string
merge 1:1 year using psh_ppp_ratioWorld.dta
drop _merge 
cap erase psh_ppp_ratioWorld.dta

ren psh_ppp_ratio* *

foreach var of varlist _all {
	label var `var' ""
}
 
tsset year
tsline Brazil China France Germany India Indonesia Japan Russia USA United_Kingdom , title("Public spending in health as " "% national income (PPP) by country 1980-2023") note("Interpretation:  Public spending on health spending typically ranges from 1-8% of GDP." "Low-income countries typically spend 1-2% on health, middle-income countries 3-4%, and high-income" "countries 6-8% of GDP, respectively.") lpattern(dash dash dash dash shortdash shortdash shortdash shortdash  ) legend(size(small) row(2)) lcolor(green red  blue cyan magenta gold orange purple brown pink ) yla(0(.02).14)

*Export 
export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataF13_large_health", modify) cell(A4) keepcellfmt


**# Figure 13f
/*------------------------------------------------------------------------------
Figure 13f. Public Spending in Education as % Gross National Income for the Largest Economies 1980-2023
------------------------------------------------------------------------------*/

*Import data
use main_dataset.dta,clear
keep if year>=1980
drop if country=="WO"

*Generate relevant variables
foreach var in gni pr tr ntr ps ehs psh pse sp ops psur ip ssur{
	g `var'_ppp=`var'/ppp_2023_eur
}

preserve
*Aggregate at the national-year level
collapse (sum) pse_ppp gni_ppp, by(year )
g pse_ppp_ratioWorld=pse_ppp/gni_ppp
drop pse_ppp gni_ppp
save pse_ppp_ratioWorld.dta,replace
restore 

merge m:1 country using largest.dta
keep if _merge==3
drop _merge
loc s countryname
		replace `s' = subinstr(`s', " ", "_", .)

*Aggregate at the region-year level
collapse (sum) pse_ppp gni_ppp, by(year countryname)

*Format in Figure format
g pse_ppp_ratio=pse_ppp/gni_ppp
drop pse_ppp gni_ppp
reshape wide pse_ppp_ratio , i(year) j(countryname) string
merge 1:1 year using pse_ppp_ratioWorld.dta
drop _merge 
cap erase pse_ppp_ratioWorld.dta

ren pse_ppp_ratio* *

foreach var of varlist _all {
	label var `var' ""
}
 
tsset year
tsline Brazil China France Germany India Indonesia Japan Russia USA United_Kingdom , title("Public spending in education as " "% national income (PPP) by country 1980-2023") note("Interpretation:  Public spending on education spending typically ranges from 2-6% of GDP." "Low-income countries typically spend 3-4% on health, middle-income countries 4-5%, and high-income" "countries 5-6% of GDP, respectively.") lpattern(dash dash dash dash shortdash shortdash shortdash shortdash  ) legend(size(small) row(2)) lcolor(green red  blue cyan magenta gold orange purple brown pink ) yla(0(.02).14)

*Export 
export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataF13_large_education", modify) cell(A4) keepcellfmt


**# Figure 14b
/*------------------------------------------------------------------------------
Figure 14b. Public Spending in Social Protecion as % Gross National Income for the Largest Economies 1980-2023
------------------------------------------------------------------------------*/
*Import data
use main_dataset.dta,clear
keep if year>=1980
drop if country=="WO"

*Generate relevant variables
foreach var in gni pr tr ntr ps ehs sp ops psur ip ssur{
	g `var'_ppp=`var'/ppp_2023_eur
}

preserve
*Aggregate at the national-year level
collapse (sum) sp_ppp gni_ppp, by(year )
g sp_ppp_ratioWorld=sp_ppp/gni_ppp
drop sp_ppp gni_ppp
save sp_ppp_ratioWorld.dta,replace
restore 

merge m:1 country using largest.dta
keep if _merge==3
drop _merge
loc s countryname
		replace `s' = subinstr(`s', " ", "_", .)

*Aggregate at the region-year level
collapse (sum) sp_ppp gni_ppp, by(year countryname)

*Format in Figure format
g sp_ppp_ratio=sp_ppp/gni_ppp
drop sp_ppp gni_ppp
reshape wide sp_ppp_ratio , i(year) j(countryname) string
merge 1:1 year using sp_ppp_ratioWorld.dta
drop _merge 
cap erase sp_ppp_ratioWorld.dta

ren sp_ppp_ratio* *

foreach var of varlist _all {
	label var `var' ""
}
 
tsset year
tsline Brazil China France Germany India Indonesia Japan Russia USA United_Kingdom , title("Public spending in social protection as " "% national income (PPP) by country 1980-2023") note("Interpretation:  Indicator of a country's commitment to social welfare programs." "High-income nations typically spend over 15% of GDP, while low-income countries often spend below 5%.") lpattern(dash dash dash dash shortdash shortdash shortdash shortdash  ) legend(size(small) row(2)) lcolor(green red  blue cyan magenta gold orange purple brown pink ) yla(0(.05).35)

*Export 
export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataF14_large", modify) cell(A4) keepcellfmt



**# Figure 15b
/*------------------------------------------------------------------------------
Figure 15b. Other Public Spending as % Gross National Income for the Largest Economies 1980-2023
------------------------------------------------------------------------------*/
*Import data
use main_dataset.dta,clear
keep if year>=1980
drop if country=="WO"

*Generate relevant variables
foreach var in gni pr tr ntr ps ehs sp ops psur ip ssur{
	g `var'_ppp=`var'/ppp_2023_eur
}

preserve
*Aggregate at the national-year level
collapse (sum) ops_ppp gni_ppp, by(year )
g ops_ppp_ratioWorld=ops_ppp/gni_ppp
drop ops_ppp gni_ppp
save ops_ppp_ratioWorld.dta,replace
restore 

merge m:1 country using largest.dta
keep if _merge==3
drop _merge
loc s countryname
		replace `s' = subinstr(`s', " ", "_", .)

*Aggregate at the region-year level
collapse (sum) ops_ppp gni_ppp, by(year countryname)

*Format in Figure format
g ops_ppp_ratio=ops_ppp/gni_ppp
drop ops_ppp gni_ppp
reshape wide ops_ppp_ratio , i(year) j(countryname) string
merge 1:1 year using ops_ppp_ratioWorld.dta
drop _merge 
cap erase ops_ppp_ratioWorld.dta

ren ops_ppp_ratio* *

foreach var of varlist _all {
	label var `var' ""
}
 
tsset year
tsline Brazil China France Germany India Indonesia Japan Russia USA United_Kingdom , title("Other public spending as " "% national income (PPP) by country 1980-2023") note("Interpretation:  Government expenditures on public services, economic affairs, public safety, environmental" "protection, housing, and cultural activities. Support for societal infrastructure and community well-being." "A significant portion of the Soviet budget was allocated to military spending, which reportedly reached between" "10% to 27% of GDP during this period.") lpattern(dash dash dash dash shortdash shortdash shortdash shortdash  ) legend(size(small) row(2)) lcolor(green red  blue cyan magenta gold orange purple brown pink ) yla(0(.05).4)

*Export 
export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataF15_large", modify) cell(A4) keepcellfmt




**# Figure 16b
/*------------------------------------------------------------------------------
Figure 16b. Primary Surplus as % Gross National Income for the Largest Economies 1980-2023
------------------------------------------------------------------------------*/
*Import data
use main_dataset.dta,clear
keep if year>=1980
drop if country=="WO"

*Generate relevant variables
foreach var in gni pr tr ntr ps ehs sp ops psur ip ssur{
	g `var'_ppp=`var'/ppp_2023_eur
}

preserve
*Aggregate at the national-year level
collapse (sum) psur_ppp gni_ppp, by(year )
g psur_ppp_ratioWorld=psur_ppp/gni_ppp
drop psur_ppp gni_ppp
save psur_ppp_ratioWorld.dta,replace
restore 

merge m:1 country using largest.dta
keep if _merge==3
drop _merge
loc s countryname
		replace `s' = subinstr(`s', " ", "_", .)

*Aggregate at the region-year level
collapse (sum) psur_ppp gni_ppp, by(year countryname)

*Format in Figure format
g psur_ppp_ratio=psur_ppp/gni_ppp
drop psur_ppp gni_ppp
reshape wide psur_ppp_ratio , i(year) j(countryname) string
merge 1:1 year using psur_ppp_ratioWorld.dta
drop _merge 
cap erase psur_ppp_ratioWorld.dta

ren psur_ppp_ratio* *

foreach var of varlist _all {
	label var `var' ""
}
 
tsset year
tsline Brazil China France Germany India Indonesia Japan Russia USA United_Kingdom , title("Primary surplus as % national income (PPP)" "by country 1980-2023") note("Interpretation:  A primary surplus indicates that a government is generating more revenue than it is spending" "on its core activities. Primary deficit could lead to increased borrowing and potential long-term fiscal challenges." "High-income countries typically have primary surpluses greater than 4.5% of GDP, middle-income countries" "range from 1-3% of GDP, while low-income countries often face primary deficits with surpluses below 1% of GDP.") lpattern(dash dash dash dash shortdash shortdash shortdash shortdash  ) legend(size(small) row(2)) lcolor(green red  blue cyan magenta gold orange purple brown pink ) yla(-.25(.05).2) yline(0)

*Export 
export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataF16_large", modify) cell(A4) keepcellfmt




**# Figure 17b
/*---------------------- --------------------------------------------------------
Figure 17b. Interest Payments as % Gross National Income for the Largest Economies 1980-2023
------------------------------------------------------------------------------*/
*Import data
use main_dataset.dta,clear
keep if year>=1980
drop if country=="WO"

*Generate relevant variables
foreach var in gni pr tr ntr ps ehs sp ops psur ip ssur{
	g `var'_ppp=`var'/ppp_2023_eur
}

preserve
*Aggregate at the national-year level
collapse (sum) ip_ppp gni_ppp, by(year )
g ip_ppp_ratioWorld=ip_ppp/gni_ppp
drop ip_ppp gni_ppp
save ip_ppp_ratioWorld.dta,replace
restore 

merge m:1 country using largest.dta
keep if _merge==3
drop _merge
loc s countryname
		replace `s' = subinstr(`s', " ", "_", .)

*Aggregate at the region-year level
collapse (sum) ip_ppp gni_ppp, by(year countryname)

*Format in Figure format
g ip_ppp_ratio=ip_ppp/gni_ppp
drop ip_ppp gni_ppp
reshape wide ip_ppp_ratio , i(year) j(countryname) string
merge 1:1 year using ip_ppp_ratioWorld.dta
drop _merge 
cap erase ip_ppp_ratioWorld.dta

ren ip_ppp_ratio* *

foreach var of varlist _all {
	label var `var' ""
}
 
tsset year
tsline Brazil China France Germany India Indonesia Japan Russia USA United_Kingdom , title("Interest payments as % national income (PPP)" "by country 1980-2023") note("Interpretation:  Financial burden of government debt relative to its total income, influencing fiscal sustainability" "and economic health." "Low-income countries typically spend over 10% of revenues on interest payments, and high-income countries" "usually less than 2% of GDP.") lpattern(dash dash dash dash shortdash shortdash shortdash shortdash  ) legend(size(small) row(2)) lcolor(green red  blue cyan magenta gold orange purple brown pink ) yla(0(.02).14) yline(0)

*Export 
export excel using "$root\GomezCarreraetal2024Macro.xlsx", sheet("DataF17_large", modify) cell(A4) keepcellfmt










